@@ -11,7 +11,9 @@ from _pytest._code.code import (
     ExceptionInfo,
     FormattedExcinfo,
     ReprExceptionInfo,
-    ExceptionChainRepr)
+    ExceptionChainRepr,
+)
+from six.moves import queue
 
 from test_source import astonly
 
@@ -22,8 +24,6 @@ except ImportError:
 else:
     invalidate_import_caches = getattr(importlib, "invalidate_caches", None)
 
-queue = py.builtin._tryimport('queue', 'Queue')
-
 failsonjython = pytest.mark.xfail("sys.platform.startswith('java')")
 
 pytest_version_info = tuple(map(int, pytest.__version__.split(".")[:3]))
@@ -75,9 +75,11 @@ def test_excinfo_getstatement():
         f()
     except ValueError:
         excinfo = _pytest._code.ExceptionInfo()
-    linenumbers = [_pytest._code.getrawcode(f).co_firstlineno - 1 + 4,
-                   _pytest._code.getrawcode(f).co_firstlineno - 1 + 1,
-                   _pytest._code.getrawcode(g).co_firstlineno - 1 + 1, ]
+    linenumbers = [
+        _pytest._code.getrawcode(f).co_firstlineno - 1 + 4,
+        _pytest._code.getrawcode(f).co_firstlineno - 1 + 1,
+        _pytest._code.getrawcode(g).co_firstlineno - 1 + 1,
+    ]
     values = list(excinfo.traceback)
     foundlinenumbers = [x.lineno for x in values]
     assert foundlinenumbers == linenumbers
@@ -85,6 +87,7 @@ def test_excinfo_getstatement():
     #    print "%s:%d  %s" %(x.path.relto(root), x.lineno, x.statement)
     # xxx
 
+
 # testchain for getentries test below
 
 
@@ -119,7 +122,7 @@ class TestTraceback_f_g_h(object):
         entries = list(tb)
         assert len(tb) == 4  # maybe fragile test
         assert len(entries) == 4  # maybe fragile test
-        names = ['f', 'g', 'h']
+        names = ["f", "g", "h"]
         for entry in entries:
             try:
                 names.remove(entry.frame.code.name)
@@ -136,14 +139,16 @@ class TestTraceback_f_g_h(object):
     @astonly
     @failsonjython
     def test_traceback_entry_getsource_in_construct(self):
-        source = _pytest._code.Source("""\
+        source = _pytest._code.Source(
+            """\
             def xyz():
                 try:
                     raise ValueError
                 except somenoname:
                     pass
             xyz()
-        """)
+        """
+        )
         try:
             exec(source.compile())
         except NameError:
@@ -168,7 +173,7 @@ class TestTraceback_f_g_h(object):
         basedir = py.path.local(pytest.__file__).dirpath()
         newtraceback = excinfo.traceback.cut(excludepath=basedir)
         for x in newtraceback:
-            if hasattr(x, 'path'):
+            if hasattr(x, "path"):
                 assert not py.path.local(x.path).relto(basedir)
         assert newtraceback[-1].frame.code.path == p
 
@@ -177,12 +182,15 @@ class TestTraceback_f_g_h(object):
         ntraceback = traceback.filter()
         assert len(ntraceback) == len(traceback) - 1
 
-    @pytest.mark.parametrize('tracebackhide, matching', [
-        (lambda info: True, True),
-        (lambda info: False, False),
-        (operator.methodcaller('errisinstance', ValueError), True),
-        (operator.methodcaller('errisinstance', IndexError), False),
-    ])
+    @pytest.mark.parametrize(
+        "tracebackhide, matching",
+        [
+            (lambda info: True, True),
+            (lambda info: False, False),
+            (operator.methodcaller("errisinstance", ValueError), True),
+            (operator.methodcaller("errisinstance", IndexError), False),
+        ],
+    )
     def test_traceback_filter_selective(self, tracebackhide, matching):
         def f():
             #
@@ -203,8 +211,8 @@ class TestTraceback_f_g_h(object):
         excinfo = pytest.raises(ValueError, h)
         traceback = excinfo.traceback
         ntraceback = traceback.filter()
-        print('old: {0!r}'.format(traceback))
-        print('new: {0!r}'.format(ntraceback))
+        print("old: {!r}".format(traceback))
+        print("new: {!r}".format(ntraceback))
 
         if matching:
             assert len(ntraceback) == len(traceback) - 2
@@ -217,6 +225,7 @@ class TestTraceback_f_g_h(object):
             if n < 10:
                 n += 1
             f(n)
+
         excinfo = pytest.raises(RuntimeError, f, 8)
         traceback = excinfo.traceback
         recindex = traceback.recursionindex()
@@ -239,6 +248,7 @@ class TestTraceback_f_g_h(object):
 
         def reraise_me():
             import sys
+
             exc, val, tb = sys.exc_info()
             py.builtin._reraise(exc, val, tb)
 
@@ -255,15 +265,16 @@ class TestTraceback_f_g_h(object):
 
     def test_traceback_messy_recursion(self):
         # XXX: simplified locally testable version
-        decorator = pytest.importorskip('decorator').decorator
+        decorator = pytest.importorskip("decorator").decorator
 
         def log(f, *k, **kw):
-            print('%s %s' % (k, kw))
+            print("%s %s" % (k, kw))
             f(*k, **kw)
+
         log = decorator(log)
 
         def fail():
-            raise ValueError('')
+            raise ValueError("")
 
         fail = log(log(fail))
 
@@ -291,7 +302,7 @@ class TestTraceback_f_g_h(object):
         co = _pytest._code.Code(h)
         assert entry.frame.code.path == co.path
         assert entry.lineno == co.firstlineno + 1
-        assert entry.frame.code.name == 'h'
+        assert entry.frame.code.name == "h"
 
     def test_traceback_getcrashentry_empty(self):
         def g():
@@ -308,16 +319,15 @@ class TestTraceback_f_g_h(object):
         co = _pytest._code.Code(g)
         assert entry.frame.code.path == co.path
         assert entry.lineno == co.firstlineno + 2
-        assert entry.frame.code.name == 'g'
+        assert entry.frame.code.name == "g"
 
 
 def test_excinfo_exconly():
     excinfo = pytest.raises(ValueError, h)
-    assert excinfo.exconly().startswith('ValueError')
-    excinfo = pytest.raises(ValueError,
-                            "raise ValueError('hello\\nworld')")
+    assert excinfo.exconly().startswith("ValueError")
+    excinfo = pytest.raises(ValueError, "raise ValueError('hello\\nworld')")
     msg = excinfo.exconly(tryshort=True)
-    assert msg.startswith('ValueError')
+    assert msg.startswith("ValueError")
     assert msg.endswith("world")
 
 
@@ -351,19 +361,18 @@ def test_excinfo_no_sourcecode():
 
 def test_excinfo_no_python_sourcecode(tmpdir):
     # XXX: simplified locally testable version
-    tmpdir.join('test.txt').write("{{ h()}}:")
+    tmpdir.join("test.txt").write("{{ h()}}:")
 
-    jinja2 = pytest.importorskip('jinja2')
+    jinja2 = pytest.importorskip("jinja2")
     loader = jinja2.FileSystemLoader(str(tmpdir))
     env = jinja2.Environment(loader=loader)
-    template = env.get_template('test.txt')
-    excinfo = pytest.raises(ValueError,
-                            template.render, h=h)
+    template = env.get_template("test.txt")
+    excinfo = pytest.raises(ValueError, template.render, h=h)
     for item in excinfo.traceback:
         print(item)  # XXX: for some reason jinja.Template.render is printed in full
         item.source  # shouldnt fail
-        if item.path.basename == 'test.txt':
-            assert str(item.source) == '{{ h()}}:'
+        if item.path.basename == "test.txt":
+            assert str(item.source) == "{{ h()}}:"
 
 
 def test_entrysource_Queue_example():
@@ -393,26 +402,25 @@ def test_codepath_Queue_example():
 def test_match_succeeds():
     with pytest.raises(ZeroDivisionError) as excinfo:
         0 // 0
-    excinfo.match(r'.*zero.*')
+    excinfo.match(r".*zero.*")
 
 
 def test_match_raises_error(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         import pytest
         def test_division_zero():
             with pytest.raises(ZeroDivisionError) as excinfo:
                 0 / 0
             excinfo.match(r'[123]+')
-    """)
+    """
+    )
     result = testdir.runpytest()
     assert result.ret != 0
-    result.stdout.fnmatch_lines([
-        "*AssertionError*Pattern*[123]*not found*",
-    ])
+    result.stdout.fnmatch_lines(["*AssertionError*Pattern*[123]*not found*"])
 
 
 class TestFormattedExcinfo(object):
-
     @pytest.fixture
     def importasmod(self, request):
         def importasmod(source):
@@ -424,6 +432,7 @@ class TestFormattedExcinfo(object):
             if invalidate_import_caches is not None:
                 invalidate_import_caches()
             return modpath.pyimport()
+
         return importasmod
 
     def excinfo_from_exec(self, source):
@@ -438,10 +447,12 @@ class TestFormattedExcinfo(object):
 
     def test_repr_source(self):
         pr = FormattedExcinfo()
-        source = _pytest._code.Source("""
+        source = _pytest._code.Source(
+            """
             def f(x):
                 pass
-        """).strip()
+        """
+        ).strip()
         pr.flow_marker = "|"
         lines = pr.get_source(source, 0)
         assert len(lines) == 2
@@ -451,19 +462,17 @@ class TestFormattedExcinfo(object):
     def test_repr_source_excinfo(self):
         """ check if indentation is right """
         pr = FormattedExcinfo()
-        excinfo = self.excinfo_from_exec("""
+        excinfo = self.excinfo_from_exec(
+            """
                 def f():
                     assert 0
                 f()
-        """)
+        """
+        )
         pr = FormattedExcinfo()
         source = pr._getentrysource(excinfo.traceback[-1])
         lines = pr.get_source(source, 1, excinfo)
-        assert lines == [
-            '    def f():',
-            '>       assert 0',
-            'E       AssertionError'
-        ]
+        assert lines == ["    def f():", ">       assert 0", "E       AssertionError"]
 
     def test_repr_source_not_existing(self):
         pr = FormattedExcinfo()
@@ -479,10 +488,14 @@ class TestFormattedExcinfo(object):
 
     def test_repr_many_line_source_not_existing(self):
         pr = FormattedExcinfo()
-        co = compile("""
+        co = compile(
+            """
 a = 1
 raise ValueError()
-""", "", "exec")
+""",
+            "",
+            "exec",
+        )
         try:
             exec(co)
         except ValueError:
@@ -497,9 +510,9 @@ raise ValueError()
 
         class FakeCode(object):
             class raw(object):
-                co_filename = '?'
+                co_filename = "?"
 
-            path = '?'
+            path = "?"
             firstlineno = 5
 
             def fullsource(self):
@@ -558,19 +571,21 @@ raise ValueError()
 
     def test_repr_local(self):
         p = FormattedExcinfo(showlocals=True)
-        loc = {'y': 5, 'z': 7, 'x': 3, '@x': 2, '__builtins__': {}}
+        loc = {"y": 5, "z": 7, "x": 3, "@x": 2, "__builtins__": {}}
         reprlocals = p.repr_locals(loc)
         assert reprlocals.lines
-        assert reprlocals.lines[0] == '__builtins__ = <builtins>'
-        assert reprlocals.lines[1] == 'x          = 3'
-        assert reprlocals.lines[2] == 'y          = 5'
-        assert reprlocals.lines[3] == 'z          = 7'
+        assert reprlocals.lines[0] == "__builtins__ = <builtins>"
+        assert reprlocals.lines[1] == "x          = 3"
+        assert reprlocals.lines[2] == "y          = 5"
+        assert reprlocals.lines[3] == "z          = 7"
 
     def test_repr_tracebackentry_lines(self, importasmod):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def func1():
                 raise ValueError("hello\\nworld")
-        """)
+        """
+        )
         excinfo = pytest.raises(ValueError, mod.func1)
         excinfo.traceback = excinfo.traceback.filter()
         p = FormattedExcinfo()
@@ -578,17 +593,17 @@ raise ValueError()
 
         # test as intermittent entry
         lines = reprtb.lines
-        assert lines[0] == '    def func1():'
+        assert lines[0] == "    def func1():"
         assert lines[1] == '>       raise ValueError("hello\\nworld")'
 
         # test as last entry
         p = FormattedExcinfo(showlocals=True)
         repr_entry = p.repr_traceback_entry(excinfo.traceback[-1], excinfo)
         lines = repr_entry.lines
-        assert lines[0] == '    def func1():'
+        assert lines[0] == "    def func1():"
         assert lines[1] == '>       raise ValueError("hello\\nworld")'
-        assert lines[2] == 'E       ValueError: hello'
-        assert lines[3] == 'E       world'
+        assert lines[2] == "E       ValueError: hello"
+        assert lines[3] == "E       world"
         assert not lines[4:]
 
         loc = repr_entry.reprlocals is not None
@@ -598,42 +613,46 @@ raise ValueError()
         # assert loc.message == "ValueError: hello"
 
     def test_repr_tracebackentry_lines2(self, importasmod):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def func1(m, x, y, z):
                 raise ValueError("hello\\nworld")
-        """)
+        """
+        )
         excinfo = pytest.raises(ValueError, mod.func1, "m" * 90, 5, 13, "z" * 120)
         excinfo.traceback = excinfo.traceback.filter()
         entry = excinfo.traceback[-1]
         p = FormattedExcinfo(funcargs=True)
         reprfuncargs = p.repr_args(entry)
-        assert reprfuncargs.args[0] == ('m', repr("m" * 90))
-        assert reprfuncargs.args[1] == ('x', '5')
-        assert reprfuncargs.args[2] == ('y', '13')
-        assert reprfuncargs.args[3] == ('z', repr("z" * 120))
+        assert reprfuncargs.args[0] == ("m", repr("m" * 90))
+        assert reprfuncargs.args[1] == ("x", "5")
+        assert reprfuncargs.args[2] == ("y", "13")
+        assert reprfuncargs.args[3] == ("z", repr("z" * 120))
 
         p = FormattedExcinfo(funcargs=True)
         repr_entry = p.repr_traceback_entry(entry)
         assert repr_entry.reprfuncargs.args == reprfuncargs.args
         tw = TWMock()
         repr_entry.toterminal(tw)
-        assert tw.lines[0] == "m = " + repr('m' * 90)
+        assert tw.lines[0] == "m = " + repr("m" * 90)
         assert tw.lines[1] == "x = 5, y = 13"
-        assert tw.lines[2] == "z = " + repr('z' * 120)
+        assert tw.lines[2] == "z = " + repr("z" * 120)
 
     def test_repr_tracebackentry_lines_var_kw_args(self, importasmod):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def func1(x, *y, **z):
                 raise ValueError("hello\\nworld")
-        """)
-        excinfo = pytest.raises(ValueError, mod.func1, 'a', 'b', c='d')
+        """
+        )
+        excinfo = pytest.raises(ValueError, mod.func1, "a", "b", c="d")
         excinfo.traceback = excinfo.traceback.filter()
         entry = excinfo.traceback[-1]
         p = FormattedExcinfo(funcargs=True)
         reprfuncargs = p.repr_args(entry)
-        assert reprfuncargs.args[0] == ('x', repr('a'))
-        assert reprfuncargs.args[1] == ('y', repr(('b',)))
-        assert reprfuncargs.args[2] == ('z', repr({'c': 'd'}))
+        assert reprfuncargs.args[0] == ("x", repr("a"))
+        assert reprfuncargs.args[1] == ("y", repr(("b",)))
+        assert reprfuncargs.args[2] == ("z", repr({"c": "d"}))
 
         p = FormattedExcinfo(funcargs=True)
         repr_entry = p.repr_traceback_entry(entry)
@@ -643,18 +662,20 @@ raise ValueError()
         assert tw.lines[0] == "x = 'a', y = ('b',), z = {'c': 'd'}"
 
     def test_repr_tracebackentry_short(self, importasmod):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def func1():
                 raise ValueError("hello")
             def entry():
                 func1()
-        """)
+        """
+        )
         excinfo = pytest.raises(ValueError, mod.entry)
         p = FormattedExcinfo(style="short")
         reprtb = p.repr_traceback_entry(excinfo.traceback[-2])
         lines = reprtb.lines
         basename = py.path.local(mod.__file__).basename
-        assert lines[0] == '    func1()'
+        assert lines[0] == "    func1()"
         assert basename in str(reprtb.reprfileloc.path)
         assert reprtb.reprfileloc.lineno == 5
 
@@ -663,17 +684,19 @@ raise ValueError()
         reprtb = p.repr_traceback_entry(excinfo.traceback[-1], excinfo)
         lines = reprtb.lines
         assert lines[0] == '    raise ValueError("hello")'
-        assert lines[1] == 'E   ValueError: hello'
+        assert lines[1] == "E   ValueError: hello"
         assert basename in str(reprtb.reprfileloc.path)
         assert reprtb.reprfileloc.lineno == 3
 
     def test_repr_tracebackentry_no(self, importasmod):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def func1():
                 raise ValueError("hello")
             def entry():
                 func1()
-        """)
+        """
+        )
         excinfo = pytest.raises(ValueError, mod.entry)
         p = FormattedExcinfo(style="no")
         p.repr_traceback_entry(excinfo.traceback[-2])
@@ -681,16 +704,18 @@ raise ValueError()
         p = FormattedExcinfo(style="no")
         reprentry = p.repr_traceback_entry(excinfo.traceback[-1], excinfo)
         lines = reprentry.lines
-        assert lines[0] == 'E   ValueError: hello'
+        assert lines[0] == "E   ValueError: hello"
         assert not lines[1:]
 
     def test_repr_traceback_tbfilter(self, importasmod):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def f(x):
                 raise ValueError(x)
             def entry():
                 f(0)
-        """)
+        """
+        )
         excinfo = pytest.raises(ValueError, mod.entry)
         p = FormattedExcinfo(tbfilter=True)
         reprtb = p.repr_traceback(excinfo)
@@ -700,15 +725,18 @@ raise ValueError()
         assert len(reprtb.reprentries) == 3
 
     def test_traceback_short_no_source(self, importasmod, monkeypatch):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def func1():
                 raise ValueError("hello")
             def entry():
                 func1()
-        """)
+        """
+        )
         excinfo = pytest.raises(ValueError, mod.entry)
         from _pytest._code.code import Code
-        monkeypatch.setattr(Code, 'path', 'bogus')
+
+        monkeypatch.setattr(Code, "path", "bogus")
         excinfo.traceback[0].frame.code.path = "bogus"
         p = FormattedExcinfo(style="short")
         reprtb = p.repr_traceback_entry(excinfo.traceback[-2])
@@ -717,18 +745,20 @@ raise ValueError()
         last_reprtb = last_p.repr_traceback_entry(excinfo.traceback[-1], excinfo)
         last_lines = last_reprtb.lines
         monkeypatch.undo()
-        assert lines[0] == '    func1()'
+        assert lines[0] == "    func1()"
 
         assert last_lines[0] == '    raise ValueError("hello")'
-        assert last_lines[1] == 'E   ValueError: hello'
+        assert last_lines[1] == "E   ValueError: hello"
 
     def test_repr_traceback_and_excinfo(self, importasmod):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def f(x):
                 raise ValueError(x)
             def entry():
                 f(0)
-        """)
+        """
+        )
         excinfo = pytest.raises(ValueError, mod.entry)
 
         for style in ("long", "short"):
@@ -747,12 +777,14 @@ raise ValueError()
             assert repr.reprcrash.message == "ValueError: 0"
 
     def test_repr_traceback_with_invalid_cwd(self, importasmod, monkeypatch):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def f(x):
                 raise ValueError(x)
             def entry():
                 f(0)
-        """)
+        """
+        )
         excinfo = pytest.raises(ValueError, mod.entry)
 
         p = FormattedExcinfo()
@@ -760,15 +792,17 @@ raise ValueError()
         def raiseos():
             raise OSError(2)
 
-        monkeypatch.setattr(os, 'getcwd', raiseos)
+        monkeypatch.setattr(os, "getcwd", raiseos)
         assert p._makepath(__file__) == __file__
         p.repr_traceback(excinfo)
 
     def test_repr_excinfo_addouterr(self, importasmod):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def entry():
                 raise ValueError()
-        """)
+        """
+        )
         excinfo = pytest.raises(ValueError, mod.entry)
         repr = excinfo.getrepr()
         repr.addsection("title", "content")
@@ -778,10 +812,12 @@ raise ValueError()
         assert twmock.lines[-2] == ("-", "title")
 
     def test_repr_excinfo_reprcrash(self, importasmod):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def entry():
                 raise ValueError()
-        """)
+        """
+        )
         excinfo = pytest.raises(ValueError, mod.entry)
         repr = excinfo.getrepr()
         assert repr.reprcrash.path.endswith("mod.py")
@@ -790,14 +826,16 @@ raise ValueError()
         assert str(repr.reprcrash).endswith("mod.py:3: ValueError")
 
     def test_repr_traceback_recursion(self, importasmod):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def rec2(x):
                 return rec1(x+1)
             def rec1(x):
                 return rec2(x-1)
             def entry():
                 rec1(42)
-        """)
+        """
+        )
         excinfo = pytest.raises(RuntimeError, mod.entry)
 
         for style in ("short", "long", "no"):
@@ -807,12 +845,14 @@ raise ValueError()
             assert str(reprtb)
 
     def test_reprexcinfo_getrepr(self, importasmod):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def f(x):
                 raise ValueError(x)
             def entry():
                 f(0)
-        """)
+        """
+        )
         excinfo = pytest.raises(ValueError, mod.entry)
 
         for style in ("short", "long", "no"):
@@ -837,12 +877,14 @@ raise ValueError()
         assert x == py.builtin._totext("я", "utf-8")
 
     def test_toterminal_long(self, importasmod):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def g(x):
                 raise ValueError(x)
             def f():
                 g(3)
-        """)
+        """
+        )
         excinfo = pytest.raises(ValueError, mod.f)
         excinfo.traceback = excinfo.traceback.filter()
         repr = excinfo.getrepr()
@@ -867,14 +909,16 @@ raise ValueError()
         assert tw.lines[12] == ":3: ValueError"
 
     def test_toterminal_long_missing_source(self, importasmod, tmpdir):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def g(x):
                 raise ValueError(x)
             def f():
                 g(3)
-        """)
+        """
+        )
         excinfo = pytest.raises(ValueError, mod.f)
-        tmpdir.join('mod.py').remove()
+        tmpdir.join("mod.py").remove()
         excinfo.traceback = excinfo.traceback.filter()
         repr = excinfo.getrepr()
         tw = TWMock()
@@ -896,14 +940,16 @@ raise ValueError()
         assert tw.lines[10] == ":3: ValueError"
 
     def test_toterminal_long_incomplete_source(self, importasmod, tmpdir):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def g(x):
                 raise ValueError(x)
             def f():
                 g(3)
-        """)
+        """
+        )
         excinfo = pytest.raises(ValueError, mod.f)
-        tmpdir.join('mod.py').write('asdf')
+        tmpdir.join("mod.py").write("asdf")
         excinfo.traceback = excinfo.traceback.filter()
         repr = excinfo.getrepr()
         tw = TWMock()
@@ -925,10 +971,12 @@ raise ValueError()
         assert tw.lines[10] == ":3: ValueError"
 
     def test_toterminal_long_filenames(self, importasmod):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def f():
                 raise ValueError()
-        """)
+        """
+        )
         excinfo = pytest.raises(ValueError, mod.f)
         tw = TWMock()
         path = py.path.local(mod.__file__)
@@ -951,20 +999,30 @@ raise ValueError()
         finally:
             old.chdir()
 
-    @pytest.mark.parametrize('reproptions', [
-        {'style': style, 'showlocals': showlocals,
-         'funcargs': funcargs, 'tbfilter': tbfilter
-         } for style in ("long", "short", "no")
-        for showlocals in (True, False)
-        for tbfilter in (True, False)
-        for funcargs in (True, False)])
+    @pytest.mark.parametrize(
+        "reproptions",
+        [
+            {
+                "style": style,
+                "showlocals": showlocals,
+                "funcargs": funcargs,
+                "tbfilter": tbfilter,
+            }
+            for style in ("long", "short", "no")
+            for showlocals in (True, False)
+            for tbfilter in (True, False)
+            for funcargs in (True, False)
+        ],
+    )
     def test_format_excinfo(self, importasmod, reproptions):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def g(x):
                 raise ValueError(x)
             def f():
                 g(3)
-        """)
+        """
+        )
         excinfo = pytest.raises(ValueError, mod.f)
         tw = py.io.TerminalWriter(stringio=True)
         repr = excinfo.getrepr(**reproptions)
@@ -972,7 +1030,8 @@ raise ValueError()
         assert tw.stringio.getvalue()
 
     def test_traceback_repr_style(self, importasmod):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def f():
                 g()
             def g():
@@ -981,7 +1040,8 @@ raise ValueError()
                 i()
             def i():
                 raise ValueError()
-        """)
+        """
+        )
         excinfo = pytest.raises(ValueError, mod.f)
         excinfo.traceback = excinfo.traceback.filter()
         excinfo.traceback[1].set_repr_style("short")
@@ -1017,7 +1077,8 @@ raise ValueError()
 
     @pytest.mark.skipif("sys.version_info[0] < 3")
     def test_exc_chain_repr(self, importasmod):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             class Err(Exception):
                 pass
             def f():
@@ -1032,7 +1093,8 @@ raise ValueError()
 
             def h():
                 raise AttributeError()
-        """)
+        """
+        )
         excinfo = pytest.raises(AttributeError, mod.f)
         r = excinfo.getrepr(style="long")
         tw = TWMock()
@@ -1045,8 +1107,8 @@ raise ValueError()
         assert tw.lines[3] == ">           g()"
         assert tw.lines[4] == ""
         line = tw.get_write_msg(5)
-        assert line.endswith('mod.py')
-        assert tw.lines[6] == ':6: '
+        assert line.endswith("mod.py")
+        assert tw.lines[6] == ":6: "
         assert tw.lines[7] == ("_ ", None)
         assert tw.lines[8] == ""
         assert tw.lines[9] == "    def g():"
@@ -1054,10 +1116,13 @@ raise ValueError()
         assert tw.lines[11] == "E       ValueError"
         assert tw.lines[12] == ""
         line = tw.get_write_msg(13)
-        assert line.endswith('mod.py')
-        assert tw.lines[14] == ':12: ValueError'
+        assert line.endswith("mod.py")
+        assert tw.lines[14] == ":12: ValueError"
         assert tw.lines[15] == ""
-        assert tw.lines[16] == "The above exception was the direct cause of the following exception:"
+        assert (
+            tw.lines[16]
+            == "The above exception was the direct cause of the following exception:"
+        )
         assert tw.lines[17] == ""
         assert tw.lines[18] == "    def f():"
         assert tw.lines[19] == "        try:"
@@ -1067,10 +1132,13 @@ raise ValueError()
         assert tw.lines[23] == "E           test_exc_chain_repr0.mod.Err"
         assert tw.lines[24] == ""
         line = tw.get_write_msg(25)
-        assert line.endswith('mod.py')
+        assert line.endswith("mod.py")
         assert tw.lines[26] == ":8: Err"
         assert tw.lines[27] == ""
-        assert tw.lines[28] == "During handling of the above exception, another exception occurred:"
+        assert (
+            tw.lines[28]
+            == "During handling of the above exception, another exception occurred:"
+        )
         assert tw.lines[29] == ""
         assert tw.lines[30] == "    def f():"
         assert tw.lines[31] == "        try:"
@@ -1081,21 +1149,22 @@ raise ValueError()
         assert tw.lines[36] == ">           h()"
         assert tw.lines[37] == ""
         line = tw.get_write_msg(38)
-        assert line.endswith('mod.py')
+        assert line.endswith("mod.py")
         assert tw.lines[39] == ":10: "
-        assert tw.lines[40] == ('_ ', None)
+        assert tw.lines[40] == ("_ ", None)
         assert tw.lines[41] == ""
         assert tw.lines[42] == "    def h():"
         assert tw.lines[43] == ">       raise AttributeError()"
         assert tw.lines[44] == "E       AttributeError"
         assert tw.lines[45] == ""
         line = tw.get_write_msg(46)
-        assert line.endswith('mod.py')
+        assert line.endswith("mod.py")
         assert tw.lines[47] == ":15: AttributeError"
 
     @pytest.mark.skipif("sys.version_info[0] < 3")
     def test_exc_repr_with_raise_from_none_chain_suppression(self, importasmod):
-        mod = importasmod("""
+        mod = importasmod(
+            """
             def f():
                 try:
                     g()
@@ -1103,7 +1172,8 @@ raise ValueError()
                     raise AttributeError() from None
             def g():
                 raise ValueError()
-        """)
+        """
+        )
         excinfo = pytest.raises(AttributeError, mod.f)
         r = excinfo.getrepr(style="long")
         tw = TWMock()
@@ -1119,15 +1189,24 @@ raise ValueError()
         assert tw.lines[6] == "E           AttributeError"
         assert tw.lines[7] == ""
         line = tw.get_write_msg(8)
-        assert line.endswith('mod.py')
+        assert line.endswith("mod.py")
         assert tw.lines[9] == ":6: AttributeError"
         assert len(tw.lines) == 10
 
     @pytest.mark.skipif("sys.version_info[0] < 3")
-    @pytest.mark.parametrize('reason, description', [
-        ('cause', 'The above exception was the direct cause of the following exception:'),
-        ('context', 'During handling of the above exception, another exception occurred:'),
-    ])
+    @pytest.mark.parametrize(
+        "reason, description",
+        [
+            (
+                "cause",
+                "The above exception was the direct cause of the following exception:",
+            ),
+            (
+                "context",
+                "During handling of the above exception, another exception occurred:",
+            ),
+        ],
+    )
     def test_exc_chain_repr_without_traceback(self, importasmod, reason, description):
         """
         Handle representation of exception chains where one of the exceptions doesn't have a
@@ -1135,8 +1214,10 @@ raise ValueError()
         module (#1984).
         """
         from _pytest.pytester import LineMatcher
-        exc_handling_code = ' from e' if reason == 'cause' else ''
-        mod = importasmod("""
+
+        exc_handling_code = " from e" if reason == "cause" else ""
+        mod = importasmod(
+            """
             def f():
                 try:
                     g()
@@ -1144,13 +1225,16 @@ raise ValueError()
                     raise RuntimeError('runtime problem'){exc_handling_code}
             def g():
                 raise ValueError('invalid value')
-        """.format(exc_handling_code=exc_handling_code))
+        """.format(
+                exc_handling_code=exc_handling_code
+            )
+        )
 
         with pytest.raises(RuntimeError) as excinfo:
             mod.f()
 
         # emulate the issue described in #1984
-        attr = '__%s__' % reason
+        attr = "__%s__" % reason
         getattr(excinfo.value, attr).__traceback__ = None
 
         r = excinfo.getrepr()
@@ -1159,19 +1243,21 @@ raise ValueError()
         r.toterminal(tw)
 
         matcher = LineMatcher(tw.stringio.getvalue().splitlines())
-        matcher.fnmatch_lines([
-            "ValueError: invalid value",
-            description,
-            "* except Exception as e:",
-            "> * raise RuntimeError('runtime problem')" + exc_handling_code,
-            "E *RuntimeError: runtime problem",
-        ])
+        matcher.fnmatch_lines(
+            [
+                "ValueError: invalid value",
+                description,
+                "* except Exception as e:",
+                "> * raise RuntimeError('runtime problem')" + exc_handling_code,
+                "E *RuntimeError: runtime problem",
+            ]
+        )
 
 
 @pytest.mark.parametrize("style", ["short", "long"])
 @pytest.mark.parametrize("encoding", [None, "utf8", "utf16"])
 def test_repr_traceback_with_unicode(style, encoding):
-    msg = u'☹'
+    msg = u"☹"
     if encoding is not None:
         msg = msg.encode(encoding)
     try:
@@ -1184,28 +1270,32 @@ def test_repr_traceback_with_unicode(style, encoding):
 
 
 def test_cwd_deleted(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         def test(tmpdir):
             tmpdir.chdir()
             tmpdir.remove()
             assert False
-    """)
+    """
+    )
     result = testdir.runpytest()
-    result.stdout.fnmatch_lines(['* 1 failed in *'])
-    assert 'INTERNALERROR' not in result.stdout.str() + result.stderr.str()
+    result.stdout.fnmatch_lines(["* 1 failed in *"])
+    assert "INTERNALERROR" not in result.stdout.str() + result.stderr.str()
 
 
 def test_exception_repr_extraction_error_on_recursion():
     """
     Ensure we can properly detect a recursion error even
-    if some locals raise error on comparision (#2459).
+    if some locals raise error on comparison (#2459).
     """
-    class numpy_like(object):
 
+    class numpy_like(object):
         def __eq__(self, other):
             if type(other) is numpy_like:
-                raise ValueError('The truth value of an array '
-                                 'with more than one element is ambiguous.')
+                raise ValueError(
+                    "The truth value of an array "
+                    "with more than one element is ambiguous."
+                )
 
     def a(x):
         return b(numpy_like())
@@ -1218,14 +1308,17 @@ def test_exception_repr_extraction_error_on_recursion():
     except:  # noqa
         from _pytest._code.code import ExceptionInfo
         from _pytest.pytester import LineMatcher
+
         exc_info = ExceptionInfo()
 
         matcher = LineMatcher(str(exc_info.getrepr()).splitlines())
-        matcher.fnmatch_lines([
-            '!!! Recursion error detected, but an error occurred locating the origin of recursion.',
-            '*The following exception happened*',
-            '*ValueError: The truth value of an array*',
-        ])
+        matcher.fnmatch_lines(
+            [
+                "!!! Recursion error detected, but an error occurred locating the origin of recursion.",
+                "*The following exception happened*",
+                "*ValueError: The truth value of an array*",
+            ]
+        )
 
 
 def test_no_recursion_index_on_recursion_error():
@@ -1234,14 +1327,16 @@ def test_no_recursion_index_on_recursion_error():
     during a recursion error (#2486).
     """
     try:
+
         class RecursionDepthError(object):
             def __getattr__(self, attr):
-                return getattr(self, '_' + attr)
+                return getattr(self, "_" + attr)
 
         RecursionDepthError().trigger
     except:  # noqa
         from _pytest._code.code import ExceptionInfo
+
         exc_info = ExceptionInfo()
-        assert 'maximum recursion' in str(exc_info.getrepr())
+        assert "maximum recursion" in str(exc_info.getrepr())
     else:
         assert 0
