@@ -18,7 +18,6 @@ def test_is_generator():
 
 
 def test_real_func_loop_limit():
-
     class Evil(object):
         def __init__(self):
             self.left = 1000
@@ -28,7 +27,7 @@ def test_real_func_loop_limit():
 
         def __getattr__(self, attr):
             if not self.left:
-                raise RuntimeError('its over')
+                raise RuntimeError("its over")
             self.left -= 1
             return self
 
@@ -39,10 +38,12 @@ def test_real_func_loop_limit():
         print(res)
 
 
-@pytest.mark.skipif(sys.version_info < (3, 4),
-                    reason='asyncio available in Python 3.4+')
+@pytest.mark.skipif(
+    sys.version_info < (3, 4), reason="asyncio available in Python 3.4+"
+)
 def test_is_generator_asyncio(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         from _pytest.compat import is_generator
         import asyncio
         @asyncio.coroutine
@@ -51,17 +52,20 @@ def test_is_generator_asyncio(testdir):
 
         def test_is_generator_asyncio():
             assert not is_generator(baz)
-    """)
+    """
+    )
     # avoid importing asyncio into pytest's own process,
     # which in turn imports logging (#8)
     result = testdir.runpytest_subprocess()
-    result.stdout.fnmatch_lines(['*1 passed*'])
+    result.stdout.fnmatch_lines(["*1 passed*"])
 
 
-@pytest.mark.skipif(sys.version_info < (3, 5),
-                    reason='async syntax available in Python 3.5+')
+@pytest.mark.skipif(
+    sys.version_info < (3, 5), reason="async syntax available in Python 3.5+"
+)
 def test_is_generator_async_syntax(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         from _pytest.compat import is_generator
         def test_is_generator_py35():
             async def foo():
@@ -72,19 +76,20 @@ def test_is_generator_async_syntax(testdir):
 
             assert not is_generator(foo)
             assert not is_generator(bar)
-    """)
+    """
+    )
     result = testdir.runpytest()
-    result.stdout.fnmatch_lines(['*1 passed*'])
+    result.stdout.fnmatch_lines(["*1 passed*"])
 
 
 class ErrorsHelper(object):
     @property
     def raise_exception(self):
-        raise Exception('exception should be catched')
+        raise Exception("exception should be catched")
 
     @property
     def raise_fail(self):
-        pytest.fail('fail should be catched')
+        pytest.fail("fail should be catched")
 
 
 def test_helper_failures():
@@ -97,5 +102,5 @@ def test_helper_failures():
 
 def test_safe_getattr():
     helper = ErrorsHelper()
-    assert safe_getattr(helper, 'raise_exception', 'default') == 'default'
-    assert safe_getattr(helper, 'raise_fail', 'default') == 'default'
+    assert safe_getattr(helper, "raise_exception", "default") == "default"
+    assert safe_getattr(helper, "raise_fail", "default") == "default"
