@@ -23,8 +23,8 @@ def assert_attr(node, **kwargs):
         if anode is not None:
             return anode.value
 
-    expected = dict((name, str(value)) for name, value in kwargs.items())
-    on_node = dict((name, nodeval(node, name)) for name in expected)
+    expected = {name: str(value) for name, value in kwargs.items()}
+    on_node = {name: nodeval(node, name) for name in expected}
     assert on_node == expected
 
 
@@ -81,7 +81,8 @@ class DomNode(object):
 
 class TestPython(object):
     def test_summing_simple(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import pytest
             def test_pass():
                 pass
@@ -95,14 +96,16 @@ class TestPython(object):
             @pytest.mark.xfail
             def test_xpass():
                 assert 1
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         assert result.ret
         node = dom.find_first_by_tag("testsuite")
         node.assert_attr(name="pytest", errors=0, failures=1, skips=2, tests=5)
 
     def test_summing_simple_with_errors(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import pytest
             @pytest.fixture
             def fixture():
@@ -119,14 +122,16 @@ class TestPython(object):
             @pytest.mark.xfail(strict=True)
             def test_xpass():
                 assert True
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         assert result.ret
         node = dom.find_first_by_tag("testsuite")
         node.assert_attr(name="pytest", errors=1, failures=2, skips=1, tests=5)
 
     def test_timing_function(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import time, pytest
             def setup_module():
                 time.sleep(0.01)
@@ -134,7 +139,8 @@ class TestPython(object):
                 time.sleep(0.01)
             def test_sleep():
                 time.sleep(0.01)
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         node = dom.find_first_by_tag("testsuite")
         tnode = node.find_first_by_tag("testcase")
@@ -142,7 +148,8 @@ class TestPython(object):
         assert round(float(val), 2) >= 0.03
 
     def test_setup_error(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import pytest
 
             @pytest.fixture
@@ -150,7 +157,8 @@ class TestPython(object):
                 raise ValueError()
             def test_function(arg):
                 pass
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         assert result.ret
         node = dom.find_first_by_tag("testsuite")
@@ -160,13 +168,15 @@ class TestPython(object):
             file="test_setup_error.py",
             line="5",
             classname="test_setup_error",
-            name="test_function")
+            name="test_function",
+        )
         fnode = tnode.find_first_by_tag("error")
         fnode.assert_attr(message="test setup failure")
         assert "ValueError" in fnode.toxml()
 
     def test_teardown_error(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import pytest
 
             @pytest.fixture
@@ -175,7 +185,8 @@ class TestPython(object):
                 raise ValueError()
             def test_function(arg):
                 pass
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         assert result.ret
         node = dom.find_first_by_tag("testsuite")
@@ -184,13 +195,15 @@ class TestPython(object):
             file="test_teardown_error.py",
             line="6",
             classname="test_teardown_error",
-            name="test_function")
+            name="test_function",
+        )
         fnode = tnode.find_first_by_tag("error")
         fnode.assert_attr(message="test teardown failure")
         assert "ValueError" in fnode.toxml()
 
     def test_call_failure_teardown_error(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import pytest
 
             @pytest.fixture
@@ -199,7 +212,8 @@ class TestPython(object):
                 raise Exception("Teardown Exception")
             def test_function(arg):
                 raise Exception("Call Exception")
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         assert result.ret
         node = dom.find_first_by_tag("testsuite")
@@ -213,11 +227,13 @@ class TestPython(object):
         snode.assert_attr(message="test teardown failure")
 
     def test_skip_contains_name_reason(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import pytest
             def test_skip():
                 pytest.skip("hello23")
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         assert result.ret == 0
         node = dom.find_first_by_tag("testsuite")
@@ -227,17 +243,20 @@ class TestPython(object):
             file="test_skip_contains_name_reason.py",
             line="1",
             classname="test_skip_contains_name_reason",
-            name="test_skip")
+            name="test_skip",
+        )
         snode = tnode.find_first_by_tag("skipped")
-        snode.assert_attr(type="pytest.skip", message="hello23", )
+        snode.assert_attr(type="pytest.skip", message="hello23")
 
     def test_mark_skip_contains_name_reason(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import pytest
             @pytest.mark.skip(reason="hello24")
             def test_skip():
                 assert True
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         assert result.ret == 0
         node = dom.find_first_by_tag("testsuite")
@@ -247,18 +266,21 @@ class TestPython(object):
             file="test_mark_skip_contains_name_reason.py",
             line="1",
             classname="test_mark_skip_contains_name_reason",
-            name="test_skip")
+            name="test_skip",
+        )
         snode = tnode.find_first_by_tag("skipped")
-        snode.assert_attr(type="pytest.skip", message="hello24", )
+        snode.assert_attr(type="pytest.skip", message="hello24")
 
     def test_mark_skipif_contains_name_reason(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import pytest
             GLOBAL_CONDITION = True
             @pytest.mark.skipif(GLOBAL_CONDITION, reason="hello25")
             def test_skip():
                 assert True
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         assert result.ret == 0
         node = dom.find_first_by_tag("testsuite")
@@ -268,28 +290,33 @@ class TestPython(object):
             file="test_mark_skipif_contains_name_reason.py",
             line="2",
             classname="test_mark_skipif_contains_name_reason",
-            name="test_skip")
+            name="test_skip",
+        )
         snode = tnode.find_first_by_tag("skipped")
-        snode.assert_attr(type="pytest.skip", message="hello25", )
+        snode.assert_attr(type="pytest.skip", message="hello25")
 
     def test_mark_skip_doesnt_capture_output(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import pytest
             @pytest.mark.skip(reason="foo")
             def test_skip():
                 print("bar!")
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         assert result.ret == 0
         node_xml = dom.find_first_by_tag("testsuite").toxml()
         assert "bar!" not in node_xml
 
     def test_classname_instance(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             class TestClass(object):
                 def test_method(self):
                     assert 0
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         assert result.ret
         node = dom.find_first_by_tag("testsuite")
@@ -299,7 +326,8 @@ class TestPython(object):
             file="test_classname_instance.py",
             line="1",
             classname="test_classname_instance.TestClass",
-            name="test_method")
+            name="test_method",
+        )
 
     def test_classname_nested_dir(self, testdir):
         p = testdir.tmpdir.ensure("sub", "test_hello.py")
@@ -313,7 +341,8 @@ class TestPython(object):
             file=os.path.join("sub", "test_hello.py"),
             line="0",
             classname="sub.test_hello",
-            name="test_func")
+            name="test_func",
+        )
 
     def test_internal_error(self, testdir):
         testdir.makeconftest("def pytest_runtest_protocol(): 0 / 0")
@@ -328,9 +357,10 @@ class TestPython(object):
         fnode.assert_attr(message="internal error")
         assert "Division" in fnode.toxml()
 
-    @pytest.mark.parametrize('junit_logging', ['no', 'system-out', 'system-err'])
+    @pytest.mark.parametrize("junit_logging", ["no", "system-out", "system-err"])
     def test_failure_function(self, testdir, junit_logging):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import logging
             import sys
 
@@ -340,9 +370,10 @@ class TestPython(object):
                 logging.info('info msg')
                 logging.warning('warning msg')
                 raise ValueError(42)
-        """)
+        """
+        )
 
-        result, dom = runandparse(testdir, '-o', 'junit_logging=%s' % junit_logging)
+        result, dom = runandparse(testdir, "-o", "junit_logging=%s" % junit_logging)
         assert result.ret
         node = dom.find_first_by_tag("testsuite")
         node.assert_attr(failures=1, tests=1)
@@ -351,7 +382,8 @@ class TestPython(object):
             file="test_failure_function.py",
             line="3",
             classname="test_failure_function",
-            name="test_fail")
+            name="test_fail",
+        )
         fnode = tnode.find_first_by_tag("failure")
         fnode.assert_attr(message="ValueError: 42")
         assert "ValueError" in fnode.toxml()
@@ -364,22 +396,24 @@ class TestPython(object):
         assert "hello-stderr" in systemerr.toxml()
         assert "info msg" not in systemerr.toxml()
 
-        if junit_logging == 'system-out':
+        if junit_logging == "system-out":
             assert "warning msg" in systemout.toxml()
             assert "warning msg" not in systemerr.toxml()
-        elif junit_logging == 'system-err':
+        elif junit_logging == "system-err":
             assert "warning msg" not in systemout.toxml()
             assert "warning msg" in systemerr.toxml()
-        elif junit_logging == 'no':
+        elif junit_logging == "no":
             assert "warning msg" not in systemout.toxml()
             assert "warning msg" not in systemerr.toxml()
 
     def test_failure_verbose_message(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import sys
             def test_fail():
                 assert 0, "An error"
-        """)
+        """
+        )
 
         result, dom = runandparse(testdir)
         node = dom.find_first_by_tag("testsuite")
@@ -388,13 +422,15 @@ class TestPython(object):
         fnode.assert_attr(message="AssertionError: An error assert 0")
 
     def test_failure_escape(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import pytest
             @pytest.mark.parametrize('arg1', "<&'", ids="<&'")
             def test_func(arg1):
                 print(arg1)
                 assert 0
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         assert result.ret
         node = dom.find_first_by_tag("testsuite")
@@ -407,19 +443,22 @@ class TestPython(object):
                 file="test_failure_escape.py",
                 line="1",
                 classname="test_failure_escape",
-                name="test_func[%s]" % char)
-            sysout = tnode.find_first_by_tag('system-out')
+                name="test_func[%s]" % char,
+            )
+            sysout = tnode.find_first_by_tag("system-out")
             text = sysout.text
-            assert text == '%s\n' % char
+            assert text == "%s\n" % char
 
     def test_junit_prefixing(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             def test_func():
                 assert 0
             class TestHello(object):
                 def test_hello(self):
                     pass
-        """)
+        """
+        )
         result, dom = runandparse(testdir, "--junitprefix=xyz")
         assert result.ret
         node = dom.find_first_by_tag("testsuite")
@@ -429,21 +468,24 @@ class TestPython(object):
             file="test_junit_prefixing.py",
             line="0",
             classname="xyz.test_junit_prefixing",
-            name="test_func")
+            name="test_func",
+        )
         tnode = node.find_nth_by_tag("testcase", 1)
         tnode.assert_attr(
             file="test_junit_prefixing.py",
             line="3",
-            classname="xyz.test_junit_prefixing."
-            "TestHello",
-            name="test_hello")
+            classname="xyz.test_junit_prefixing." "TestHello",
+            name="test_hello",
+        )
 
     def test_xfailure_function(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import pytest
             def test_xfail():
                 pytest.xfail("42")
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         assert not result.ret
         node = dom.find_first_by_tag("testsuite")
@@ -453,18 +495,40 @@ class TestPython(object):
             file="test_xfailure_function.py",
             line="1",
             classname="test_xfailure_function",
-            name="test_xfail")
+            name="test_xfail",
+        )
         fnode = tnode.find_first_by_tag("skipped")
         fnode.assert_attr(message="expected test failure")
         # assert "ValueError" in fnode.toxml()
 
+    def test_xfail_captures_output_once(self, testdir):
+        testdir.makepyfile(
+            """
+            import sys
+            import pytest
+
+            @pytest.mark.xfail()
+            def test_fail():
+                sys.stdout.write('XFAIL This is stdout')
+                sys.stderr.write('XFAIL This is stderr')
+                assert 0
+        """
+        )
+        result, dom = runandparse(testdir)
+        node = dom.find_first_by_tag("testsuite")
+        tnode = node.find_first_by_tag("testcase")
+        assert len(tnode.find_by_tag("system-err")) == 1
+        assert len(tnode.find_by_tag("system-out")) == 1
+
     def test_xfailure_xpass(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import pytest
             @pytest.mark.xfail
             def test_xpass():
                 pass
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         # assert result.ret
         node = dom.find_first_by_tag("testsuite")
@@ -474,15 +538,18 @@ class TestPython(object):
             file="test_xfailure_xpass.py",
             line="1",
             classname="test_xfailure_xpass",
-            name="test_xpass")
+            name="test_xpass",
+        )
 
     def test_xfailure_xpass_strict(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import pytest
             @pytest.mark.xfail(strict=True, reason="This needs to fail!")
             def test_xpass():
                 pass
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         # assert result.ret
         node = dom.find_first_by_tag("testsuite")
@@ -492,7 +559,8 @@ class TestPython(object):
             file="test_xfailure_xpass_strict.py",
             line="1",
             classname="test_xfailure_xpass_strict",
-            name="test_xpass")
+            name="test_xpass",
+        )
         fnode = tnode.find_first_by_tag("failure")
         fnode.assert_attr(message="[XPASS(strict)] This needs to fail!")
 
@@ -503,22 +571,23 @@ class TestPython(object):
         node = dom.find_first_by_tag("testsuite")
         node.assert_attr(errors=1, tests=1)
         tnode = node.find_first_by_tag("testcase")
-        tnode.assert_attr(
-            file="test_collect_error.py",
-            name="test_collect_error")
+        tnode.assert_attr(file="test_collect_error.py", name="test_collect_error")
         assert tnode["line"] is None
         fnode = tnode.find_first_by_tag("error")
         fnode.assert_attr(message="collection failure")
         assert "SyntaxError" in fnode.toxml()
 
     def test_unicode(self, testdir):
-        value = 'hx\xc4\x85\xc4\x87\n'
-        testdir.makepyfile("""
+        value = "hx\xc4\x85\xc4\x87\n"
+        testdir.makepyfile(
+            """
             # coding: latin1
             def test_hello():
                 print (%r)
                 assert 0
-        """ % value)
+        """
+            % value
+        )
         result, dom = runandparse(testdir)
         assert result.ret == 1
         tnode = dom.find_first_by_tag("testcase")
@@ -528,22 +597,26 @@ class TestPython(object):
 
     def test_assertion_binchars(self, testdir):
         """this test did fail when the escaping wasnt strict"""
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
 
             M1 = '\x01\x02\x03\x04'
             M2 = '\x01\x02\x03\x05'
 
             def test_str_compare():
                 assert M1 == M2
-            """)
+            """
+        )
         result, dom = runandparse(testdir)
         print(dom.toxml())
 
     def test_pass_captures_stdout(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             def test_pass():
                 print('hello-stdout')
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         node = dom.find_first_by_tag("testsuite")
         pnode = node.find_first_by_tag("testcase")
@@ -551,11 +624,13 @@ class TestPython(object):
         assert "hello-stdout" in systemout.toxml()
 
     def test_pass_captures_stderr(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import sys
             def test_pass():
                 sys.stderr.write('hello-stderr')
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         node = dom.find_first_by_tag("testsuite")
         pnode = node.find_first_by_tag("testcase")
@@ -563,7 +638,8 @@ class TestPython(object):
         assert "hello-stderr" in systemout.toxml()
 
     def test_setup_error_captures_stdout(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import pytest
 
             @pytest.fixture
@@ -572,7 +648,8 @@ class TestPython(object):
                 raise ValueError()
             def test_function(arg):
                 pass
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         node = dom.find_first_by_tag("testsuite")
         pnode = node.find_first_by_tag("testcase")
@@ -580,7 +657,8 @@ class TestPython(object):
         assert "hello-stdout" in systemout.toxml()
 
     def test_setup_error_captures_stderr(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import sys
             import pytest
 
@@ -590,7 +668,8 @@ class TestPython(object):
                 raise ValueError()
             def test_function(arg):
                 pass
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         node = dom.find_first_by_tag("testsuite")
         pnode = node.find_first_by_tag("testcase")
@@ -598,7 +677,8 @@ class TestPython(object):
         assert "hello-stderr" in systemout.toxml()
 
     def test_avoid_double_stdout(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             import sys
             import pytest
 
@@ -609,7 +689,8 @@ class TestPython(object):
                 raise ValueError()
             def test_function(arg):
                 sys.stdout.write('hello-stdout call')
-        """)
+        """
+        )
         result, dom = runandparse(testdir)
         node = dom.find_first_by_tag("testsuite")
         pnode = node.find_first_by_tag("testcase")
@@ -620,8 +701,8 @@ class TestPython(object):
 
 def test_mangle_test_address():
     from _pytest.junitxml import mangle_test_address
-    address = '::'.join(
-        ["a/my.py.thing.py", "Class", "()", "method", "[a-1-::]"])
+
+    address = "::".join(["a/my.py.thing.py", "Class", "()", "method", "[a-1-::]"])
     newnames = mangle_test_address(address)
     assert newnames == ["a.my.py.thing", "Class", "method", "[a-1-::]"]
 
@@ -639,11 +720,12 @@ def test_dont_configure_on_slaves(tmpdir):
 
         junitprefix = None
         # XXX: shouldnt need tmpdir ?
-        xmlpath = str(tmpdir.join('junix.xml'))
+        xmlpath = str(tmpdir.join("junix.xml"))
         register = gotten.append
 
     fake_config = FakeConfig()
     from _pytest import junitxml
+
     junitxml.pytest_configure(fake_config)
     assert len(gotten) == 1
     FakeConfig.slaveinput = None
@@ -653,7 +735,8 @@ def test_dont_configure_on_slaves(tmpdir):
 
 class TestNonPython(object):
     def test_summing_simple(self, testdir):
-        testdir.makeconftest("""
+        testdir.makeconftest(
+            """
             import pytest
             def pytest_collect_file(path, parent):
                 if path.ext == ".xyz":
@@ -666,7 +749,8 @@ class TestNonPython(object):
                     raise ValueError(42)
                 def repr_failure(self, excinfo):
                     return "custom item runtest failed"
-        """)
+        """
+        )
         testdir.tmpdir.join("myfile.xyz").write("hello")
         result, dom = runandparse(testdir)
         assert result.ret
@@ -681,33 +765,37 @@ class TestNonPython(object):
 
 def test_nullbyte(testdir):
     # A null byte can not occur in XML (see section 2.2 of the spec)
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         import sys
         def test_print_nullbyte():
             sys.stdout.write('Here the null -->' + chr(0) + '<--')
             sys.stdout.write('In repr form -->' + repr(chr(0)) + '<--')
             assert False
-    """)
-    xmlf = testdir.tmpdir.join('junit.xml')
-    testdir.runpytest('--junitxml=%s' % xmlf)
+    """
+    )
+    xmlf = testdir.tmpdir.join("junit.xml")
+    testdir.runpytest("--junitxml=%s" % xmlf)
     text = xmlf.read()
-    assert '\x00' not in text
-    assert '#x00' in text
+    assert "\x00" not in text
+    assert "#x00" in text
 
 
 def test_nullbyte_replace(testdir):
     # Check if the null byte gets replaced
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         import sys
         def test_print_nullbyte():
             sys.stdout.write('Here the null -->' + chr(0) + '<--')
             sys.stdout.write('In repr form -->' + repr(chr(0)) + '<--')
             assert False
-    """)
-    xmlf = testdir.tmpdir.join('junit.xml')
-    testdir.runpytest('--junitxml=%s' % xmlf)
+    """
+    )
+    xmlf = testdir.tmpdir.join("junit.xml")
+    testdir.runpytest("--junitxml=%s" % xmlf)
     text = xmlf.read()
-    assert '#x0' in text
+    assert "#x0" in text
 
 
 def test_invalid_xml_escape():
@@ -724,9 +812,20 @@ def test_invalid_xml_escape():
         unichr(65)
     except NameError:
         unichr = chr
-    invalid = (0x00, 0x1, 0xB, 0xC, 0xE, 0x19, 27,  # issue #126
-               0xD800, 0xDFFF, 0xFFFE, 0x0FFFF)  # , 0x110000)
-    valid = (0x9, 0xA, 0x20, )
+    invalid = (
+        0x00,
+        0x1,
+        0xB,
+        0xC,
+        0xE,
+        0x19,
+        27,  # issue #126
+        0xD800,
+        0xDFFF,
+        0xFFFE,
+        0x0FFFF,
+    )  # , 0x110000)
+    valid = (0x9, 0xA, 0x20)
     # 0xD, 0xD7FF, 0xE000, 0xFFFD, 0x10000, 0x10FFFF)
 
     from _pytest.junitxml import bin_xml_escape
@@ -734,34 +833,36 @@ def test_invalid_xml_escape():
     for i in invalid:
         got = bin_xml_escape(unichr(i)).uniobj
         if i <= 0xFF:
-            expected = '#x%02X' % i
+            expected = "#x%02X" % i
         else:
-            expected = '#x%04X' % i
+            expected = "#x%04X" % i
         assert got == expected
     for i in valid:
         assert chr(i) == bin_xml_escape(unichr(i)).uniobj
 
 
 def test_logxml_path_expansion(tmpdir, monkeypatch):
-    home_tilde = py.path.local(os.path.expanduser('~')).join('test.xml')
+    home_tilde = py.path.local(os.path.expanduser("~")).join("test.xml")
 
-    xml_tilde = LogXML('~%stest.xml' % tmpdir.sep, None)
+    xml_tilde = LogXML("~%stest.xml" % tmpdir.sep, None)
     assert xml_tilde.logfile == home_tilde
 
     # this is here for when $HOME is not set correct
     monkeypatch.setenv("HOME", tmpdir)
-    home_var = os.path.normpath(os.path.expandvars('$HOME/test.xml'))
+    home_var = os.path.normpath(os.path.expandvars("$HOME/test.xml"))
 
-    xml_var = LogXML('$HOME%stest.xml' % tmpdir.sep, None)
+    xml_var = LogXML("$HOME%stest.xml" % tmpdir.sep, None)
     assert xml_var.logfile == home_var
 
 
 def test_logxml_changingdir(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         def test_func():
             import os
             os.chdir("a")
-    """)
+    """
+    )
     testdir.tmpdir.mkdir("a")
     result = testdir.runpytest("--junitxml=a/x.xml")
     assert result.ret == 0
@@ -770,10 +871,12 @@ def test_logxml_changingdir(testdir):
 
 def test_logxml_makedir(testdir):
     """--junitxml should automatically create directories for the xml file"""
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         def test_pass():
             pass
-    """)
+    """
+    )
     result = testdir.runpytest("--junitxml=path/to/results.xml")
     assert result.ret == 0
     assert testdir.tmpdir.join("path/to/results.xml").check()
@@ -786,12 +889,14 @@ def test_logxml_check_isdir(testdir):
 
 
 def test_escaped_parametrized_names_xml(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         import pytest
         @pytest.mark.parametrize('char', [u"\\x00"])
         def test_func(char):
             assert char
-    """)
+    """
+    )
     result, dom = runandparse(testdir)
     assert result.ret == 0
     node = dom.find_first_by_tag("testcase")
@@ -799,33 +904,36 @@ def test_escaped_parametrized_names_xml(testdir):
 
 
 def test_double_colon_split_function_issue469(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         import pytest
         @pytest.mark.parametrize('param', ["double::colon"])
         def test_func(param):
             pass
-    """)
+    """
+    )
     result, dom = runandparse(testdir)
     assert result.ret == 0
     node = dom.find_first_by_tag("testcase")
     node.assert_attr(classname="test_double_colon_split_function_issue469")
-    node.assert_attr(name='test_func[double::colon]')
+    node.assert_attr(name="test_func[double::colon]")
 
 
 def test_double_colon_split_method_issue469(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         import pytest
         class TestClass(object):
             @pytest.mark.parametrize('param', ["double::colon"])
             def test_func(self, param):
                 pass
-    """)
+    """
+    )
     result, dom = runandparse(testdir)
     assert result.ret == 0
     node = dom.find_first_by_tag("testcase")
-    node.assert_attr(
-        classname="test_double_colon_split_method_issue469.TestClass")
-    node.assert_attr(name='test_func[double::colon]')
+    node.assert_attr(classname="test_double_colon_split_method_issue469.TestClass")
+    node.assert_attr(name="test_func[double::colon]")
 
 
 def test_unicode_issue368(testdir):
@@ -838,7 +946,7 @@ def test_unicode_issue368(testdir):
         longrepr = ustr
         sections = []
         nodeid = "something"
-        location = 'tests/filename.py', 42, 'TestClass.method'
+        location = "tests/filename.py", 42, "TestClass.method"
 
     test_report = Report()
 
@@ -859,7 +967,8 @@ def test_unicode_issue368(testdir):
 
 
 def test_record_property(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         import pytest
 
         @pytest.fixture
@@ -867,33 +976,37 @@ def test_record_property(testdir):
             record_property("bar", 1)
         def test_record(record_property, other):
             record_property("foo", "<1");
-    """)
-    result, dom = runandparse(testdir, '-rwv')
+    """
+    )
+    result, dom = runandparse(testdir, "-rwv")
     node = dom.find_first_by_tag("testsuite")
     tnode = node.find_first_by_tag("testcase")
-    psnode = tnode.find_first_by_tag('properties')
-    pnodes = psnode.find_by_tag('property')
+    psnode = tnode.find_first_by_tag("properties")
+    pnodes = psnode.find_by_tag("property")
     pnodes[0].assert_attr(name="bar", value="1")
     pnodes[1].assert_attr(name="foo", value="<1")
 
 
 def test_record_property_same_name(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         def test_record_with_same_name(record_property):
             record_property("foo", "bar")
             record_property("foo", "baz")
-    """)
-    result, dom = runandparse(testdir, '-rw')
+    """
+    )
+    result, dom = runandparse(testdir, "-rw")
     node = dom.find_first_by_tag("testsuite")
     tnode = node.find_first_by_tag("testcase")
-    psnode = tnode.find_first_by_tag('properties')
-    pnodes = psnode.find_by_tag('property')
+    psnode = tnode.find_first_by_tag("properties")
+    pnodes = psnode.find_by_tag("property")
     pnodes[0].assert_attr(name="foo", value="bar")
     pnodes[1].assert_attr(name="foo", value="baz")
 
 
 def test_record_attribute(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         import pytest
 
         @pytest.fixture
@@ -901,16 +1014,16 @@ def test_record_attribute(testdir):
             record_xml_attribute("bar", 1)
         def test_record(record_xml_attribute, other):
             record_xml_attribute("foo", "<1");
-    """)
-    result, dom = runandparse(testdir, '-rw')
+    """
+    )
+    result, dom = runandparse(testdir, "-rw")
     node = dom.find_first_by_tag("testsuite")
     tnode = node.find_first_by_tag("testcase")
     tnode.assert_attr(bar="1")
     tnode.assert_attr(foo="<1")
-    result.stdout.fnmatch_lines([
-        'test_record_attribute.py::test_record',
-        '*record_xml_attribute*experimental*',
-    ])
+    result.stdout.fnmatch_lines(
+        ["test_record_attribute.py::test_record", "*record_xml_attribute*experimental*"]
+    )
 
 
 def test_random_report_log_xdist(testdir):
@@ -918,54 +1031,59 @@ def test_random_report_log_xdist(testdir):
     with nodes from several nodes overlapping, so junitxml must cope with that
     to produce correct reports. #1064
     """
-    pytest.importorskip('xdist')
-    testdir.makepyfile("""
+    pytest.importorskip("xdist")
+    testdir.makepyfile(
+        """
         import pytest, time
         @pytest.mark.parametrize('i', list(range(30)))
         def test_x(i):
             assert i != 22
-    """)
-    _, dom = runandparse(testdir, '-n2')
+    """
+    )
+    _, dom = runandparse(testdir, "-n2")
     suite_node = dom.find_first_by_tag("testsuite")
     failed = []
     for case_node in suite_node.find_by_tag("testcase"):
-        if case_node.find_first_by_tag('failure'):
-            failed.append(case_node['name'])
+        if case_node.find_first_by_tag("failure"):
+            failed.append(case_node["name"])
 
-    assert failed == ['test_x[22]']
+    assert failed == ["test_x[22]"]
 
 
 def test_runs_twice(testdir):
-    f = testdir.makepyfile('''
+    f = testdir.makepyfile(
+        """
         def test_pass():
             pass
-    ''')
+    """
+    )
 
     result, dom = runandparse(testdir, f, f)
-    assert 'INTERNALERROR' not in result.stdout.str()
-    first, second = [x['classname'] for x in dom.find_by_tag("testcase")]
+    assert "INTERNALERROR" not in result.stdout.str()
+    first, second = [x["classname"] for x in dom.find_by_tag("testcase")]
     assert first == second
 
 
-@pytest.mark.xfail(reason='hangs', run=False)
+@pytest.mark.xfail(reason="hangs", run=False)
 def test_runs_twice_xdist(testdir):
-    pytest.importorskip('xdist')
-    f = testdir.makepyfile('''
+    pytest.importorskip("xdist")
+    f = testdir.makepyfile(
+        """
         def test_pass():
             pass
-    ''')
+    """
+    )
 
-    result, dom = runandparse(
-        testdir, f,
-        '--dist', 'each', '--tx', '2*popen',)
-    assert 'INTERNALERROR' not in result.stdout.str()
-    first, second = [x['classname'] for x in dom.find_by_tag("testcase")]
+    result, dom = runandparse(testdir, f, "--dist", "each", "--tx", "2*popen")
+    assert "INTERNALERROR" not in result.stdout.str()
+    first, second = [x["classname"] for x in dom.find_by_tag("testcase")]
     assert first == second
 
 
 def test_fancy_items_regression(testdir):
     # issue 1259
-    testdir.makeconftest("""
+    testdir.makeconftest(
+        """
         import pytest
         class FunItem(pytest.Item):
             def runtest(self):
@@ -985,32 +1103,34 @@ def test_fancy_items_regression(testdir):
         def pytest_collect_file(path, parent):
             if path.check(ext='.py'):
                 return FunCollector(path, parent)
-    """)
+    """
+    )
 
-    testdir.makepyfile('''
+    testdir.makepyfile(
+        """
         def test_pass():
             pass
-    ''')
+    """
+    )
 
     result, dom = runandparse(testdir)
 
-    assert 'INTERNALERROR' not in result.stdout.str()
+    assert "INTERNALERROR" not in result.stdout.str()
 
     items = sorted(
-        '%(classname)s %(name)s %(file)s' % x
-
-        for x in dom.find_by_tag("testcase"))
+        "%(classname)s %(name)s %(file)s" % x for x in dom.find_by_tag("testcase")
+    )
     import pprint
+
     pprint.pprint(items)
     assert items == [
-        u'conftest a conftest.py',
-        u'conftest a conftest.py',
-        u'conftest b conftest.py',
-        u'test_fancy_items_regression a test_fancy_items_regression.py',
-        u'test_fancy_items_regression a test_fancy_items_regression.py',
-        u'test_fancy_items_regression b test_fancy_items_regression.py',
-        u'test_fancy_items_regression test_pass'
-        u' test_fancy_items_regression.py',
+        u"conftest a conftest.py",
+        u"conftest a conftest.py",
+        u"conftest b conftest.py",
+        u"test_fancy_items_regression a test_fancy_items_regression.py",
+        u"test_fancy_items_regression a test_fancy_items_regression.py",
+        u"test_fancy_items_regression b test_fancy_items_regression.py",
+        u"test_fancy_items_regression test_pass" u" test_fancy_items_regression.py",
     ]
 
 
@@ -1024,26 +1144,26 @@ def test_global_properties(testdir):
         nodeid = "test_node_id"
 
     log.pytest_sessionstart()
-    log.add_global_property('foo', 1)
-    log.add_global_property('bar', 2)
+    log.add_global_property("foo", 1)
+    log.add_global_property("bar", 2)
     log.pytest_sessionfinish()
 
     dom = minidom.parse(str(path))
 
-    properties = dom.getElementsByTagName('properties')
+    properties = dom.getElementsByTagName("properties")
 
-    assert (properties.length == 1), "There must be one <properties> node"
+    assert properties.length == 1, "There must be one <properties> node"
 
-    property_list = dom.getElementsByTagName('property')
+    property_list = dom.getElementsByTagName("property")
 
-    assert (property_list.length == 2), "There most be only 2 property nodes"
+    assert property_list.length == 2, "There most be only 2 property nodes"
 
-    expected = {'foo': '1', 'bar': '2'}
+    expected = {"foo": "1", "bar": "2"}
     actual = {}
 
     for p in property_list:
-        k = str(p.getAttribute('name'))
-        v = str(p.getAttribute('value'))
+        k = str(p.getAttribute("name"))
+        v = str(p.getAttribute("value"))
         actual[k] = v
 
     assert actual == expected
@@ -1059,7 +1179,7 @@ def test_url_property(testdir):
         longrepr = "FooBarBaz"
         sections = []
         nodeid = "something"
-        location = 'tests/filename.py', 42, 'TestClass.method'
+        location = "tests/filename.py", 42, "TestClass.method"
         url = test_url
 
     test_report = Report()
@@ -1069,27 +1189,35 @@ def test_url_property(testdir):
     node_reporter.append_failure(test_report)
     log.pytest_sessionfinish()
 
-    test_case = minidom.parse(str(path)).getElementsByTagName('testcase')[0]
+    test_case = minidom.parse(str(path)).getElementsByTagName("testcase")[0]
 
-    assert (test_case.getAttribute('url') == test_url), "The URL did not get written to the xml"
+    assert (
+        test_case.getAttribute("url") == test_url
+    ), "The URL did not get written to the xml"
 
 
-@pytest.mark.parametrize('suite_name', ['my_suite', ''])
+@pytest.mark.parametrize("suite_name", ["my_suite", ""])
 def test_set_suite_name(testdir, suite_name):
     if suite_name:
-        testdir.makeini("""
+        testdir.makeini(
+            """
             [pytest]
-            junit_suite_name={0}
-        """.format(suite_name))
+            junit_suite_name={}
+        """.format(
+                suite_name
+            )
+        )
         expected = suite_name
     else:
-        expected = 'pytest'
-    testdir.makepyfile("""
+        expected = "pytest"
+    testdir.makepyfile(
+        """
         import pytest
 
         def test_func():
             pass
-    """)
+    """
+    )
     result, dom = runandparse(testdir)
     assert result.ret == 0
     node = dom.find_first_by_tag("testsuite")
