@@ -7,7 +7,8 @@ from _pytest.main import EXIT_NOTESTSCOLLECTED
 
 class SessionTests(object):
     def test_basic_testitem_events(self, testdir):
-        tfile = testdir.makepyfile("""
+        tfile = testdir.makepyfile(
+            """
             def test_one():
                 pass
             def test_one_one():
@@ -17,7 +18,8 @@ class SessionTests(object):
             class TestClass(object):
                 def test_two(self, someargs):
                     pass
-        """)
+        """
+        )
         reprec = testdir.inline_run(tfile)
         passed, skipped, failed = reprec.listoutcomes()
         assert len(skipped) == 0
@@ -37,26 +39,31 @@ class SessionTests(object):
         # assert colreports[1].report.failed
 
     def test_nested_import_error(self, testdir):
-        tfile = testdir.makepyfile("""
+        tfile = testdir.makepyfile(
+            """
             import import_fails
             def test_this():
                 assert import_fails.a == 1
-        """, import_fails="""
+        """,
+            import_fails="""
             import does_not_work
             a = 1
-        """)
+        """,
+        )
         reprec = testdir.inline_run(tfile)
         values = reprec.getfailedcollections()
         assert len(values) == 1
         out = str(values[0].longrepr)
-        assert out.find('does_not_work') != -1
+        assert out.find("does_not_work") != -1
 
     def test_raises_output(self, testdir):
-        reprec = testdir.inline_runsource("""
+        reprec = testdir.inline_runsource(
+            """
             import pytest
             def test_raises_doesnt():
                 pytest.raises(ValueError, int, "3")
-        """)
+        """
+        )
         passed, skipped, failed = reprec.listoutcomes()
         assert len(failed) == 1
         out = failed[0].longrepr.reprcrash.message
@@ -65,13 +72,15 @@ class SessionTests(object):
             pytest.fail("incorrect raises() output")
 
     def test_generator_yields_None(self, testdir):
-        reprec = testdir.inline_runsource("""
+        reprec = testdir.inline_runsource(
+            """
             def test_1():
                 yield None
-        """)
+        """
+        )
         failures = reprec.getfailedcollections()
         out = failures[0].longrepr.reprcrash.message
-        i = out.find('TypeError')
+        i = out.find("TypeError")
         assert i != -1
 
     def test_syntax_error_module(self, testdir):
@@ -79,29 +88,36 @@ class SessionTests(object):
         values = reprec.getfailedcollections()
         assert len(values) == 1
         out = str(values[0].longrepr)
-        assert out.find(str('not python')) != -1
+        assert out.find(str("not python")) != -1
 
     def test_exit_first_problem(self, testdir):
-        reprec = testdir.inline_runsource("""
+        reprec = testdir.inline_runsource(
+            """
             def test_one(): assert 0
             def test_two(): assert 0
-        """, '--exitfirst')
+        """,
+            "--exitfirst",
+        )
         passed, skipped, failed = reprec.countoutcomes()
         assert failed == 1
         assert passed == skipped == 0
 
     def test_maxfail(self, testdir):
-        reprec = testdir.inline_runsource("""
+        reprec = testdir.inline_runsource(
+            """
             def test_one(): assert 0
             def test_two(): assert 0
             def test_three(): assert 0
-        """, '--maxfail=2')
+        """,
+            "--maxfail=2",
+        )
         passed, skipped, failed = reprec.countoutcomes()
         assert failed == 2
         assert passed == skipped == 0
 
     def test_broken_repr(self, testdir):
-        p = testdir.makepyfile("""
+        p = testdir.makepyfile(
+            """
             import pytest
             class BrokenRepr1(object):
                 foo=0
@@ -117,21 +133,30 @@ class SessionTests(object):
                     t = BrokenRepr1()
                     assert t.foo == 1
 
-        """)
+        """
+        )
         reprec = testdir.inline_run(p)
         passed, skipped, failed = reprec.listoutcomes()
         assert len(failed) == 1
         out = failed[0].longrepr.reprcrash.message
-        assert out.find("""[Exception("Ha Ha fooled you, I'm a broken repr().") raised in repr()]""") != -1  # '
+        assert (
+            out.find(
+                """[Exception("Ha Ha fooled you, I'm a broken repr().") raised in repr()]"""
+            )
+            != -1
+        )  # '
 
     def test_skip_file_by_conftest(self, testdir):
-        testdir.makepyfile(conftest="""
+        testdir.makepyfile(
+            conftest="""
             import pytest
             def pytest_collect_file():
                 pytest.skip("intentional")
-        """, test_file="""
+        """,
+            test_file="""
             def test_one(): pass
-        """)
+        """,
+        )
         try:
             reprec = testdir.inline_run(testdir.tmpdir)
         except pytest.skip.Exception:
@@ -142,9 +167,9 @@ class SessionTests(object):
 
 
 class TestNewSession(SessionTests):
-
     def test_order_of_execution(self, testdir):
-        reprec = testdir.inline_runsource("""
+        reprec = testdir.inline_runsource(
+            """
             values = []
             def test_1():
                 values.append(1)
@@ -162,7 +187,8 @@ class TestNewSession(SessionTests):
                     self.reslist.append(3)
                 def test_4(self):
                     assert self.reslist == [1,2,1,2,3]
-        """)
+        """
+        )
         passed, skipped, failed = reprec.countoutcomes()
         assert failed == skipped == 0
         assert passed == 7
@@ -182,9 +208,9 @@ class TestNewSession(SessionTests):
                     pass
             """,
             test_three="xxxdsadsadsadsa",
-            __init__=""
+            __init__="",
         )
-        reprec = testdir.inline_run('--collect-only', p.dirpath())
+        reprec = testdir.inline_run("--collect-only", p.dirpath())
 
         itemstarted = reprec.getcalls("pytest_itemcollected")
         assert len(itemstarted) == 3
@@ -214,9 +240,12 @@ class TestNewSession(SessionTests):
 
 
 def test_plugin_specify(testdir):
-    pytest.raises(ImportError, """
+    pytest.raises(
+        ImportError,
+        """
             testdir.parseconfig("-p", "nqweotexistent")
-    """)
+    """,
+    )
     # pytest.raises(ImportError,
     #    "config.do_configure(config)"
     # )
@@ -224,7 +253,7 @@ def test_plugin_specify(testdir):
 
 def test_plugin_already_exists(testdir):
     config = testdir.parseconfig("-p", "terminal")
-    assert config.option.plugins == ['terminal']
+    assert config.option.plugins == ["terminal"]
     config._do_configure()
     config._ensure_unconfigure()
 
@@ -241,21 +270,26 @@ def test_exclude(testdir):
 
 
 def test_deselect(testdir):
-    testdir.makepyfile(test_a="""
+    testdir.makepyfile(
+        test_a="""
         import pytest
         def test_a1(): pass
         @pytest.mark.parametrize('b', range(3))
         def test_a2(b): pass
-    """)
-    result = testdir.runpytest("-v", "--deselect=test_a.py::test_a2[1]", "--deselect=test_a.py::test_a2[2]")
+    """
+    )
+    result = testdir.runpytest(
+        "-v", "--deselect=test_a.py::test_a2[1]", "--deselect=test_a.py::test_a2[2]"
+    )
     assert result.ret == 0
     result.stdout.fnmatch_lines(["*2 passed, 2 deselected*"])
     for line in result.stdout.lines:
-        assert not line.startswith(('test_a.py::test_a2[1]', 'test_a.py::test_a2[2]'))
+        assert not line.startswith(("test_a.py::test_a2[1]", "test_a.py::test_a2[2]"))
 
 
 def test_sessionfinish_with_start(testdir):
-    testdir.makeconftest("""
+    testdir.makeconftest(
+        """
         import os
         values = []
         def pytest_sessionstart():
@@ -265,35 +299,43 @@ def test_sessionfinish_with_start(testdir):
         def pytest_sessionfinish():
             assert values[0] == os.getcwd()
 
-    """)
+    """
+    )
     res = testdir.runpytest("--collect-only")
     assert res.ret == EXIT_NOTESTSCOLLECTED
 
 
 @pytest.mark.parametrize("path", ["root", "{relative}/root", "{environment}/root"])
 def test_rootdir_option_arg(testdir, monkeypatch, path):
-    monkeypatch.setenv('PY_ROOTDIR_PATH', str(testdir.tmpdir))
-    path = path.format(relative=str(testdir.tmpdir),
-                       environment='$PY_ROOTDIR_PATH')
+    monkeypatch.setenv("PY_ROOTDIR_PATH", str(testdir.tmpdir))
+    path = path.format(relative=str(testdir.tmpdir), environment="$PY_ROOTDIR_PATH")
 
     rootdir = testdir.mkdir("root")
     rootdir.mkdir("tests")
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         import os
         def test_one():
             assert 1
-    """)
+    """
+    )
 
     result = testdir.runpytest("--rootdir={}".format(path))
-    result.stdout.fnmatch_lines(['*rootdir: {}/root, inifile:*'.format(testdir.tmpdir), "*1 passed*"])
+    result.stdout.fnmatch_lines(
+        ["*rootdir: {}/root, inifile:*".format(testdir.tmpdir), "*1 passed*"]
+    )
 
 
 def test_rootdir_wrong_option_arg(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         import os
         def test_one():
             assert 1
-    """)
+    """
+    )
 
     result = testdir.runpytest("--rootdir=wrong_dir")
-    result.stderr.fnmatch_lines(["*Directory *wrong_dir* not found. Check your '--rootdir' option.*"])
+    result.stderr.fnmatch_lines(
+        ["*Directory *wrong_dir* not found. Check your '--rootdir' option.*"]
+    )
