@@ -5,21 +5,24 @@ import gc
 
 
 def test_simple_unittest(testdir):
-    testpath = testdir.makepyfile("""
+    testpath = testdir.makepyfile(
+        """
         import unittest
         class MyTestCase(unittest.TestCase):
             def testpassing(self):
                 self.assertEqual('foo', 'foo')
             def test_failing(self):
                 self.assertEqual('foo', 'bar')
-    """)
+    """
+    )
     reprec = testdir.inline_run(testpath)
     assert reprec.matchreport("testpassing").passed
     assert reprec.matchreport("test_failing").failed
 
 
 def test_runTest_method(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         import unittest
         class MyTestCaseWithRunTest(unittest.TestCase):
             def runTest(self):
@@ -29,29 +32,35 @@ def test_runTest_method(testdir):
                 self.assertEqual('foo', 'foo')
             def test_something(self):
                 pass
-        """)
+        """
+    )
     result = testdir.runpytest("-v")
-    result.stdout.fnmatch_lines("""
+    result.stdout.fnmatch_lines(
+        """
         *MyTestCaseWithRunTest::runTest*
         *MyTestCaseWithoutRunTest::test_something*
         *2 passed*
-    """)
+    """
+    )
 
 
 def test_isclasscheck_issue53(testdir):
-    testpath = testdir.makepyfile("""
+    testpath = testdir.makepyfile(
+        """
         import unittest
         class _E(object):
             def __getattr__(self, tag):
                 pass
         E = _E()
-    """)
+    """
+    )
     result = testdir.runpytest(testpath)
     assert result.ret == EXIT_NOTESTSCOLLECTED
 
 
 def test_setup(testdir):
-    testpath = testdir.makepyfile("""
+    testpath = testdir.makepyfile(
+        """
         import unittest
         class MyTestCase(unittest.TestCase):
             def setUp(self):
@@ -64,15 +73,17 @@ def test_setup(testdir):
             def teardown_method(self, method):
                 assert 0, "42"
 
-    """)
+    """
+    )
     reprec = testdir.inline_run("-s", testpath)
     assert reprec.matchreport("test_both", when="call").passed
     rep = reprec.matchreport("test_both", when="teardown")
-    assert rep.failed and '42' in str(rep.longrepr)
+    assert rep.failed and "42" in str(rep.longrepr)
 
 
 def test_setUpModule(testdir):
-    testpath = testdir.makepyfile("""
+    testpath = testdir.makepyfile(
+        """
         values = []
 
         def setUpModule():
@@ -86,15 +97,15 @@ def test_setUpModule(testdir):
 
         def test_world():
             assert values == [1]
-        """)
+        """
+    )
     result = testdir.runpytest(testpath)
-    result.stdout.fnmatch_lines([
-        "*2 passed*",
-    ])
+    result.stdout.fnmatch_lines(["*2 passed*"])
 
 
 def test_setUpModule_failing_no_teardown(testdir):
-    testpath = testdir.makepyfile("""
+    testpath = testdir.makepyfile(
+        """
         values = []
 
         def setUpModule():
@@ -105,7 +116,8 @@ def test_setUpModule_failing_no_teardown(testdir):
 
         def test_hello():
             pass
-    """)
+    """
+    )
     reprec = testdir.inline_run(testpath)
     reprec.assertoutcome(passed=0, failed=1)
     call = reprec.getcalls("pytest_runtest_setup")[0]
@@ -113,20 +125,23 @@ def test_setUpModule_failing_no_teardown(testdir):
 
 
 def test_new_instances(testdir):
-    testpath = testdir.makepyfile("""
+    testpath = testdir.makepyfile(
+        """
         import unittest
         class MyTestCase(unittest.TestCase):
             def test_func1(self):
                 self.x = 2
             def test_func2(self):
                 assert not hasattr(self, 'x')
-    """)
+    """
+    )
     reprec = testdir.inline_run(testpath)
     reprec.assertoutcome(passed=2)
 
 
 def test_teardown(testdir):
-    testpath = testdir.makepyfile("""
+    testpath = testdir.makepyfile(
+        """
         import unittest
         class MyTestCase(unittest.TestCase):
             values = []
@@ -137,7 +152,8 @@ def test_teardown(testdir):
         class Second(unittest.TestCase):
             def test_check(self):
                 self.assertEqual(MyTestCase.values, [None])
-    """)
+    """
+    )
     reprec = testdir.inline_run(testpath)
     passed, skipped, failed = reprec.countoutcomes()
     assert failed == 0, failed
@@ -153,7 +169,8 @@ def test_teardown_issue1649(testdir):
     The TestCase will not be cleaned up if the test fails, because it
     would then exist in the stackframe.
     """
-    testpath = testdir.makepyfile("""
+    testpath = testdir.makepyfile(
+        """
         import unittest
         class TestCaseObjectsShouldBeCleanedUp(unittest.TestCase):
             def setUp(self):
@@ -161,15 +178,17 @@ def test_teardown_issue1649(testdir):
             def test_demo(self):
                 pass
 
-    """)
+    """
+    )
     testdir.inline_run("-s", testpath)
     gc.collect()
     for obj in gc.get_objects():
-        assert type(obj).__name__ != 'TestCaseObjectsShouldBeCleanedUp'
+        assert type(obj).__name__ != "TestCaseObjectsShouldBeCleanedUp"
 
 
 def test_unittest_skip_issue148(testdir):
-    testpath = testdir.makepyfile("""
+    testpath = testdir.makepyfile(
+        """
         import unittest
 
         @unittest.skip("hello")
@@ -182,33 +201,39 @@ def test_unittest_skip_issue148(testdir):
             @classmethod
             def tearDownClass(self):
                 xxx
-    """)
+    """
+    )
     reprec = testdir.inline_run(testpath)
     reprec.assertoutcome(skipped=1)
 
 
 def test_method_and_teardown_failing_reporting(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         import unittest, pytest
         class TC(unittest.TestCase):
             def tearDown(self):
                 assert 0, "down1"
             def test_method(self):
                 assert False, "down2"
-    """)
+    """
+    )
     result = testdir.runpytest("-s")
     assert result.ret == 1
-    result.stdout.fnmatch_lines([
-        "*tearDown*",
-        "*assert 0*",
-        "*test_method*",
-        "*assert False*",
-        "*1 failed*1 error*",
-    ])
+    result.stdout.fnmatch_lines(
+        [
+            "*tearDown*",
+            "*assert 0*",
+            "*test_method*",
+            "*assert False*",
+            "*1 failed*1 error*",
+        ]
+    )
 
 
 def test_setup_failure_is_shown(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         import unittest
         import pytest
         class TC(unittest.TestCase):
@@ -217,19 +242,17 @@ def test_setup_failure_is_shown(testdir):
             def test_method(self):
                 print ("never42")
                 xyz
-    """)
+    """
+    )
     result = testdir.runpytest("-s")
     assert result.ret == 1
-    result.stdout.fnmatch_lines([
-        "*setUp*",
-        "*assert 0*down1*",
-        "*1 failed*",
-    ])
-    assert 'never42' not in result.stdout.str()
+    result.stdout.fnmatch_lines(["*setUp*", "*assert 0*down1*", "*1 failed*"])
+    assert "never42" not in result.stdout.str()
 
 
 def test_setup_setUpClass(testdir):
-    testpath = testdir.makepyfile("""
+    testpath = testdir.makepyfile(
+        """
         import unittest
         import pytest
         class MyTestCase(unittest.TestCase):
@@ -246,13 +269,15 @@ def test_setup_setUpClass(testdir):
                 cls.x -= 1
         def test_teareddown():
             assert MyTestCase.x == 0
-    """)
+    """
+    )
     reprec = testdir.inline_run(testpath)
     reprec.assertoutcome(passed=3)
 
 
 def test_setup_class(testdir):
-    testpath = testdir.makepyfile("""
+    testpath = testdir.makepyfile(
+        """
         import unittest
         import pytest
         class MyTestCase(unittest.TestCase):
@@ -267,14 +292,16 @@ def test_setup_class(testdir):
                 cls.x -= 1
         def test_teareddown():
             assert MyTestCase.x == 0
-    """)
+    """
+    )
     reprec = testdir.inline_run(testpath)
     reprec.assertoutcome(passed=3)
 
 
-@pytest.mark.parametrize("type", ['Error', 'Failure'])
+@pytest.mark.parametrize("type", ["Error", "Failure"])
 def test_testcase_adderrorandfailure_defers(testdir, type):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         from unittest import TestCase
         import pytest
         class MyTestCase(TestCase):
@@ -288,14 +315,17 @@ def test_testcase_adderrorandfailure_defers(testdir, type):
                     pytest.fail("add%s should not raise")
             def test_hello(self):
                 pass
-    """ % (type, type))
+    """
+        % (type, type)
+    )
     result = testdir.runpytest()
-    assert 'should not raise' not in result.stdout.str()
+    assert "should not raise" not in result.stdout.str()
 
 
-@pytest.mark.parametrize("type", ['Error', 'Failure'])
+@pytest.mark.parametrize("type", ["Error", "Failure"])
 def test_testcase_custom_exception_info(testdir, type):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         from unittest import TestCase
         import py, pytest
         import _pytest._code
@@ -316,36 +346,44 @@ def test_testcase_custom_exception_info(testdir, type):
                     mp.undo()
             def test_hello(self):
                 pass
-    """ % locals())
+    """
+        % locals()
+    )
     result = testdir.runpytest()
-    result.stdout.fnmatch_lines([
-        "NOTE: Incompatible Exception Representation*",
-        "*ZeroDivisionError*",
-        "*1 failed*",
-    ])
+    result.stdout.fnmatch_lines(
+        [
+            "NOTE: Incompatible Exception Representation*",
+            "*ZeroDivisionError*",
+            "*1 failed*",
+        ]
+    )
 
 
 def test_testcase_totally_incompatible_exception_info(testdir):
-    item, = testdir.getitems("""
+    item, = testdir.getitems(
+        """
         from unittest import TestCase
         class MyTestCase(TestCase):
             def test_hello(self):
                 pass
-    """)
+    """
+    )
     item.addError(None, 42)
     excinfo = item._excinfo.pop(0)
-    assert 'ERROR: Unknown Incompatible' in str(excinfo.getrepr())
+    assert "ERROR: Unknown Incompatible" in str(excinfo.getrepr())
 
 
 def test_module_level_pytestmark(testdir):
-    testpath = testdir.makepyfile("""
+    testpath = testdir.makepyfile(
+        """
         import unittest
         import pytest
         pytestmark = pytest.mark.xfail
         class MyTestCase(unittest.TestCase):
             def test_func1(self):
                 assert 0
-    """)
+    """
+    )
     reprec = testdir.inline_run(testpath, "-s")
     reprec.assertoutcome(skipped=1)
 
@@ -355,30 +393,35 @@ class TestTrialUnittest(object):
         cls.ut = pytest.importorskip("twisted.trial.unittest")
         # on windows trial uses a socket for a reactor and apparently doesn't close it properly
         # https://twistedmatrix.com/trac/ticket/9227
-        cls.ignore_unclosed_socket_warning = ('-W', 'always')
+        cls.ignore_unclosed_socket_warning = ("-W", "always")
 
     def test_trial_testcase_runtest_not_collected(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             from twisted.trial.unittest import TestCase
 
             class TC(TestCase):
                 def test_hello(self):
                     pass
-        """)
+        """
+        )
         reprec = testdir.inline_run(*self.ignore_unclosed_socket_warning)
         reprec.assertoutcome(passed=1)
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             from twisted.trial.unittest import TestCase
 
             class TC(TestCase):
                 def runTest(self):
                     pass
-        """)
+        """
+        )
         reprec = testdir.inline_run(*self.ignore_unclosed_socket_warning)
         reprec.assertoutcome(passed=1)
 
     def test_trial_exceptions_with_skips(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             from twisted.trial import unittest
             import pytest
             class TC(unittest.TestCase):
@@ -409,24 +452,31 @@ class TestTrialUnittest(object):
                     pytest.skip("skip_in_setup_class")
                 def test_method(self):
                     pass
-        """)
+        """
+        )
         from _pytest.compat import _is_unittest_unexpected_success_a_failure
+
         should_fail = _is_unittest_unexpected_success_a_failure()
         result = testdir.runpytest("-rxs", *self.ignore_unclosed_socket_warning)
-        result.stdout.fnmatch_lines_random([
-            "*XFAIL*test_trial_todo*",
-            "*trialselfskip*",
-            "*skip_in_setup_class*",
-            "*iwanto*",
-            "*i2wanto*",
-            "*sys.version_info*",
-            "*skip_in_method*",
-            "*1 failed*4 skipped*3 xfailed*" if should_fail else "*4 skipped*3 xfail*1 xpass*",
-        ])
+        result.stdout.fnmatch_lines_random(
+            [
+                "*XFAIL*test_trial_todo*",
+                "*trialselfskip*",
+                "*skip_in_setup_class*",
+                "*iwanto*",
+                "*i2wanto*",
+                "*sys.version_info*",
+                "*skip_in_method*",
+                "*1 failed*4 skipped*3 xfailed*"
+                if should_fail
+                else "*4 skipped*3 xfail*1 xpass*",
+            ]
+        )
         assert result.ret == (1 if should_fail else 0)
 
     def test_trial_error(self, testdir):
-        testdir.makepyfile("""
+        testdir.makepyfile(
+            """
             from twisted.trial.unittest import TestCase
             from twisted.internet.defer import Deferred
             from twisted.internet import reactor
@@ -460,81 +510,97 @@ class TestTrialUnittest(object):
                     reactor.callLater(0.3, d.callback, None)
                     return d
                 # will crash both at test time and at teardown
-        """)
+        """
+        )
         result = testdir.runpytest()
-        result.stdout.fnmatch_lines([
-            "*ERRORS*",
-            "*DelayedCalls*",
-            "*test_four*",
-            "*NameError*crash*",
-            "*test_one*",
-            "*NameError*crash*",
-            "*test_three*",
-            "*DelayedCalls*",
-            "*test_two*",
-            "*crash*",
-        ])
+        result.stdout.fnmatch_lines(
+            [
+                "*ERRORS*",
+                "*DelayedCalls*",
+                "*test_four*",
+                "*NameError*crash*",
+                "*test_one*",
+                "*NameError*crash*",
+                "*test_three*",
+                "*DelayedCalls*",
+                "*test_two*",
+                "*crash*",
+            ]
+        )
 
     def test_trial_pdb(self, testdir):
-        p = testdir.makepyfile("""
+        p = testdir.makepyfile(
+            """
             from twisted.trial import unittest
             import pytest
             class TC(unittest.TestCase):
                 def test_hello(self):
                     assert 0, "hellopdb"
-        """)
+        """
+        )
         child = testdir.spawn_pytest(p)
         child.expect("hellopdb")
         child.sendeof()
 
     def test_trial_testcase_skip_property(self, testdir):
-        testpath = testdir.makepyfile("""
+        testpath = testdir.makepyfile(
+            """
             from twisted.trial import unittest
             class MyTestCase(unittest.TestCase):
                 skip = 'dont run'
                 def test_func(self):
                     pass
-            """)
+            """
+        )
         reprec = testdir.inline_run(testpath, "-s")
         reprec.assertoutcome(skipped=1)
 
     def test_trial_testfunction_skip_property(self, testdir):
-        testpath = testdir.makepyfile("""
+        testpath = testdir.makepyfile(
+            """
             from twisted.trial import unittest
             class MyTestCase(unittest.TestCase):
                 def test_func(self):
                     pass
                 test_func.skip = 'dont run'
-            """)
+            """
+        )
         reprec = testdir.inline_run(testpath, "-s")
         reprec.assertoutcome(skipped=1)
 
     def test_trial_testcase_todo_property(self, testdir):
-        testpath = testdir.makepyfile("""
+        testpath = testdir.makepyfile(
+            """
             from twisted.trial import unittest
             class MyTestCase(unittest.TestCase):
                 todo = 'dont run'
                 def test_func(self):
                     assert 0
-            """)
+            """
+        )
         reprec = testdir.inline_run(testpath, "-s")
         reprec.assertoutcome(skipped=1)
 
     def test_trial_testfunction_todo_property(self, testdir):
-        testpath = testdir.makepyfile("""
+        testpath = testdir.makepyfile(
+            """
             from twisted.trial import unittest
             class MyTestCase(unittest.TestCase):
                 def test_func(self):
                     assert 0
                 test_func.todo = 'dont run'
-            """)
-        reprec = testdir.inline_run(testpath, "-s", *self.ignore_unclosed_socket_warning)
+            """
+        )
+        reprec = testdir.inline_run(
+            testpath, "-s", *self.ignore_unclosed_socket_warning
+        )
         reprec.assertoutcome(skipped=1)
 
 
 def test_djangolike_testcase(testdir):
     # contributed from Morten Breekevold
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         from unittest import TestCase, main
 
         class DjangoLikeTestCase(TestCase):
@@ -574,32 +640,38 @@ def test_djangolike_testcase(testdir):
 
             def _post_teardown(self):
                 print ("_post_teardown()")
-    """)
+    """
+    )
     result = testdir.runpytest("-s")
     assert result.ret == 0
-    result.stdout.fnmatch_lines([
-        "*_pre_setup()*",
-        "*setUp()*",
-        "*test_thing()*",
-        "*tearDown()*",
-        "*_post_teardown()*",
-    ])
+    result.stdout.fnmatch_lines(
+        [
+            "*_pre_setup()*",
+            "*setUp()*",
+            "*test_thing()*",
+            "*tearDown()*",
+            "*_post_teardown()*",
+        ]
+    )
 
 
 def test_unittest_not_shown_in_traceback(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         import unittest
         class t(unittest.TestCase):
             def test_hello(self):
                 x = 3
                 self.assertEqual(x, 4)
-    """)
+    """
+    )
     res = testdir.runpytest()
     assert "failUnlessEqual" not in res.stdout.str()
 
 
 def test_unorderable_types(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         import unittest
         class TestJoinEmpty(unittest.TestCase):
             pass
@@ -610,27 +682,31 @@ def test_unorderable_types(testdir):
             Test.__name__ = "TestFoo"
             return Test
         TestFoo = make_test()
-    """)
+    """
+    )
     result = testdir.runpytest()
     assert "TypeError" not in result.stdout.str()
     assert result.ret == EXIT_NOTESTSCOLLECTED
 
 
 def test_unittest_typerror_traceback(testdir):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         import unittest
         class TestJoinEmpty(unittest.TestCase):
             def test_hello(self, arg1):
                 pass
-    """)
+    """
+    )
     result = testdir.runpytest()
     assert "TypeError" in result.stdout.str()
     assert result.ret == 1
 
 
-@pytest.mark.parametrize('runner', ['pytest', 'unittest'])
+@pytest.mark.parametrize("runner", ["pytest", "unittest"])
 def test_unittest_expected_failure_for_failing_test_is_xfail(testdir, runner):
-    script = testdir.makepyfile("""
+    script = testdir.makepyfile(
+        """
         import unittest
         class MyTestCase(unittest.TestCase):
             @unittest.expectedFailure
@@ -638,25 +714,23 @@ def test_unittest_expected_failure_for_failing_test_is_xfail(testdir, runner):
                 assert False
         if __name__ == '__main__':
             unittest.main()
-    """)
-    if runner == 'pytest':
+    """
+    )
+    if runner == "pytest":
         result = testdir.runpytest("-rxX")
-        result.stdout.fnmatch_lines([
-            "*XFAIL*MyTestCase*test_failing_test_is_xfail*",
-            "*1 xfailed*",
-        ])
+        result.stdout.fnmatch_lines(
+            ["*XFAIL*MyTestCase*test_failing_test_is_xfail*", "*1 xfailed*"]
+        )
     else:
         result = testdir.runpython(script)
-        result.stderr.fnmatch_lines([
-            "*1 test in*",
-            "*OK*(expected failures=1)*",
-        ])
+        result.stderr.fnmatch_lines(["*1 test in*", "*OK*(expected failures=1)*"])
     assert result.ret == 0
 
 
-@pytest.mark.parametrize('runner', ['pytest', 'unittest'])
+@pytest.mark.parametrize("runner", ["pytest", "unittest"])
 def test_unittest_expected_failure_for_passing_test_is_fail(testdir, runner):
-    script = testdir.makepyfile("""
+    script = testdir.makepyfile(
+        """
         import unittest
         class MyTestCase(unittest.TestCase):
             @unittest.expectedFailure
@@ -664,31 +738,32 @@ def test_unittest_expected_failure_for_passing_test_is_fail(testdir, runner):
                 assert True
         if __name__ == '__main__':
             unittest.main()
-    """)
+    """
+    )
     from _pytest.compat import _is_unittest_unexpected_success_a_failure
+
     should_fail = _is_unittest_unexpected_success_a_failure()
-    if runner == 'pytest':
+    if runner == "pytest":
         result = testdir.runpytest("-rxX")
-        result.stdout.fnmatch_lines([
-            "*MyTestCase*test_passing_test_is_fail*",
-            "*1 failed*" if should_fail else "*1 xpassed*",
-        ])
+        result.stdout.fnmatch_lines(
+            [
+                "*MyTestCase*test_passing_test_is_fail*",
+                "*1 failed*" if should_fail else "*1 xpassed*",
+            ]
+        )
     else:
         result = testdir.runpython(script)
-        result.stderr.fnmatch_lines([
-            "*1 test in*",
-            "*(unexpected successes=1)*",
-        ])
+        result.stderr.fnmatch_lines(["*1 test in*", "*(unexpected successes=1)*"])
 
     assert result.ret == (1 if should_fail else 0)
 
 
-@pytest.mark.parametrize('fix_type, stmt', [
-    ('fixture', 'return'),
-    ('yield_fixture', 'yield'),
-])
+@pytest.mark.parametrize(
+    "fix_type, stmt", [("fixture", "return"), ("yield_fixture", "yield")]
+)
 def test_unittest_setup_interaction(testdir, fix_type, stmt):
-    testdir.makepyfile("""
+    testdir.makepyfile(
+        """
         import unittest
         import pytest
         class MyTestCase(unittest.TestCase):
@@ -710,13 +785,17 @@ def test_unittest_setup_interaction(testdir, fix_type, stmt):
 
             def test_classattr(self):
                 assert self.__class__.hello == "world"
-    """.format(fix_type=fix_type, stmt=stmt))
+    """.format(
+            fix_type=fix_type, stmt=stmt
+        )
+    )
     result = testdir.runpytest()
     result.stdout.fnmatch_lines("*3 passed*")
 
 
 def test_non_unittest_no_setupclass_support(testdir):
-    testpath = testdir.makepyfile("""
+    testpath = testdir.makepyfile(
+        """
         class TestFoo(object):
             x = 0
 
@@ -734,13 +813,15 @@ def test_non_unittest_no_setupclass_support(testdir):
         def test_not_teareddown():
             assert TestFoo.x == 0
 
-    """)
+    """
+    )
     reprec = testdir.inline_run(testpath)
     reprec.assertoutcome(passed=2)
 
 
 def test_no_teardown_if_setupclass_failed(testdir):
-    testpath = testdir.makepyfile("""
+    testpath = testdir.makepyfile(
+        """
         import unittest
 
         class MyTestCase(unittest.TestCase):
@@ -760,63 +841,77 @@ def test_no_teardown_if_setupclass_failed(testdir):
 
         def test_notTornDown():
             assert MyTestCase.x == 1
-    """)
+    """
+    )
     reprec = testdir.inline_run(testpath)
     reprec.assertoutcome(passed=1, failed=1)
 
 
 def test_issue333_result_clearing(testdir):
-    testdir.makeconftest("""
+    testdir.makeconftest(
+        """
         import pytest
         @pytest.hookimpl(hookwrapper=True)
         def pytest_runtest_call(item):
             yield
             assert 0
-    """)
-    testdir.makepyfile("""
+    """
+    )
+    testdir.makepyfile(
+        """
         import unittest
         class TestIt(unittest.TestCase):
             def test_func(self):
                 0/0
-    """)
+    """
+    )
 
     reprec = testdir.inline_run()
     reprec.assertoutcome(failed=1)
 
 
 def test_unittest_raise_skip_issue748(testdir):
-    testdir.makepyfile(test_foo="""
+    testdir.makepyfile(
+        test_foo="""
         import unittest
 
         class MyTestCase(unittest.TestCase):
             def test_one(self):
                 raise unittest.SkipTest('skipping due to reasons')
-    """)
-    result = testdir.runpytest("-v", '-rs')
-    result.stdout.fnmatch_lines("""
+    """
+    )
+    result = testdir.runpytest("-v", "-rs")
+    result.stdout.fnmatch_lines(
+        """
         *SKIP*[1]*test_foo.py*skipping due to reasons*
         *1 skipped*
-    """)
+    """
+    )
 
 
 def test_unittest_skip_issue1169(testdir):
-    testdir.makepyfile(test_foo="""
+    testdir.makepyfile(
+        test_foo="""
         import unittest
 
         class MyTestCase(unittest.TestCase):
             @unittest.skip("skipping due to reasons")
             def test_skip(self):
                  self.fail()
-        """)
-    result = testdir.runpytest("-v", '-rs')
-    result.stdout.fnmatch_lines("""
+        """
+    )
+    result = testdir.runpytest("-v", "-rs")
+    result.stdout.fnmatch_lines(
+        """
         *SKIP*[1]*skipping due to reasons*
         *1 skipped*
-    """)
+    """
+    )
 
 
 def test_class_method_containing_test_issue1558(testdir):
-    testdir.makepyfile(test_foo="""
+    testdir.makepyfile(
+        test_foo="""
         import unittest
 
         class MyTestCase(unittest.TestCase):
@@ -825,6 +920,72 @@ def test_class_method_containing_test_issue1558(testdir):
             def test_should_not_run(self):
                 pass
             test_should_not_run.__test__ = False
-    """)
+    """
+    )
     reprec = testdir.inline_run()
     reprec.assertoutcome(passed=1)
+
+
+@pytest.mark.issue(3498)
+@pytest.mark.parametrize(
+    "base", ["six.moves.builtins.object", "unittest.TestCase", "unittest2.TestCase"]
+)
+def test_usefixtures_marker_on_unittest(base, testdir):
+    module = base.rsplit(".", 1)[0]
+    pytest.importorskip(module)
+    testdir.makepyfile(
+        conftest="""
+        import pytest
+
+        @pytest.fixture(scope='function')
+        def fixture1(request, monkeypatch):
+            monkeypatch.setattr(request.instance, 'fixture1', True )
+
+
+        @pytest.fixture(scope='function')
+        def fixture2(request, monkeypatch):
+            monkeypatch.setattr(request.instance, 'fixture2', True )
+
+        def node_and_marks(item):
+            print(item.nodeid)
+            for mark in item.iter_markers():
+                print("  ", mark)
+
+        @pytest.fixture(autouse=True)
+        def my_marks(request):
+            node_and_marks(request.node)
+
+        def pytest_collection_modifyitems(items):
+            for item in items:
+               node_and_marks(item)
+
+        """
+    )
+
+    testdir.makepyfile(
+        """
+        import pytest
+        import {module}
+
+        class Tests({base}):
+            fixture1 = False
+            fixture2 = False
+
+            @pytest.mark.usefixtures("fixture1")
+            def test_one(self):
+                assert self.fixture1
+                assert not self.fixture2
+
+            @pytest.mark.usefixtures("fixture1", "fixture2")
+            def test_two(self):
+                assert self.fixture1
+                assert self.fixture2
+
+
+    """.format(
+            module=module, base=base
+        )
+    )
+
+    result = testdir.runpytest("-s")
+    result.assert_outcomes(passed=2)
